@@ -1,3 +1,9 @@
+
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
+
+
 #include "derivedclass.h"
 #include <assert.h>
 
