@@ -45,6 +45,8 @@
 #endif
 
 
+
+
 GWEN_INHERIT(GWEN_CRYPT_TOKEN, GWEN_CRYPT_TOKEN_OHBCI)
 
 
@@ -1067,7 +1069,7 @@ int GWEN_Crypt_TokenOHBCI__Decode(GWEN_CRYPT_TOKEN *ct, GWEN_BUFFER *dbuf) {
     }
     else {
       GWEN_CRYPT_TOKEN_KEYINFO *ki;
-      uint8_t kbuf[256];
+      uint8_t kbuf[GWEN_CRYPT_KEYRSA_MAX_KEYLENGTH];
       uint32_t klen;
 
       /* create key info */
@@ -1156,7 +1158,7 @@ int GWEN_Crypt_TokenOHBCI__Decode(GWEN_CRYPT_TOKEN *ct, GWEN_BUFFER *dbuf) {
     }
     else {
       GWEN_CRYPT_TOKEN_KEYINFO *ki;
-      uint8_t kbuf[256];
+      uint8_t kbuf[GWEN_CRYPT_KEYRSA_MAX_KEYLENGTH];
       uint32_t klen;
 
       /* create key info */
@@ -1235,7 +1237,7 @@ int GWEN_Crypt_TokenOHBCI__Decode(GWEN_CRYPT_TOKEN *ct, GWEN_BUFFER *dbuf) {
     }
     else {
       GWEN_CRYPT_TOKEN_KEYINFO *ki;
-      uint8_t kbuf[256];
+      uint8_t kbuf[GWEN_CRYPT_KEYRSA_MAX_KEYLENGTH];
       uint32_t klen;
 
       /* create key info */
@@ -1322,7 +1324,7 @@ int GWEN_Crypt_TokenOHBCI__Decode(GWEN_CRYPT_TOKEN *ct, GWEN_BUFFER *dbuf) {
     }
     else {
       GWEN_CRYPT_TOKEN_KEYINFO *ki;
-      uint8_t kbuf[256];
+      uint8_t kbuf[GWEN_CRYPT_KEYRSA_MAX_KEYLENGTH];
       uint32_t klen;
 
       /* create key info */
@@ -1399,7 +1401,7 @@ int GWEN_Crypt_TokenOHBCI__Decode(GWEN_CRYPT_TOKEN *ct, GWEN_BUFFER *dbuf) {
     }
     else {
       GWEN_CRYPT_TOKEN_KEYINFO *ki;
-      uint8_t kbuf[256];
+      uint8_t kbuf[GWEN_CRYPT_KEYRSA_MAX_KEYLENGTH];
       uint32_t klen;
 
       /* create key info */
@@ -1481,7 +1483,7 @@ int GWEN_Crypt_TokenOHBCI__Decode(GWEN_CRYPT_TOKEN *ct, GWEN_BUFFER *dbuf) {
     }
     else {
       GWEN_CRYPT_TOKEN_KEYINFO *ki;
-      uint8_t kbuf[256];
+      uint8_t kbuf[GWEN_CRYPT_KEYRSA_MAX_KEYLENGTH];
       uint32_t klen;
 
       /* create key info */
@@ -1562,7 +1564,7 @@ int GWEN_Crypt_TokenOHBCI__Decode(GWEN_CRYPT_TOKEN *ct, GWEN_BUFFER *dbuf) {
     }
     else {
       GWEN_CRYPT_TOKEN_KEYINFO *ki;
-      uint8_t kbuf[256];
+      uint8_t kbuf[GWEN_CRYPT_KEYRSA_MAX_KEYLENGTH];
       uint32_t klen;
 
       /* create key info */
