@@ -29,7 +29,6 @@
 #define GWENHYWFAR_PLUGIN_OLDDB_H
 
 
-#include <gwenhywfar/bufferedio.h>
 #include <gwenhywfar/db.h>
 #include <gwenhywfar/dbio.h>
 #include <gwenhywfar/stringlist.h>
@@ -44,25 +43,18 @@ GWEN_PLUGIN *dbio_olddb_factory(GWEN_PLUGIN_MANAGER *pm,
 
 
 static int GWEN_DBIO_OldDb_Export(GWEN_DBIO *dbio,
-				  GWEN_IO_LAYER *io,
+				  GWEN_SYNCIO *sio,
 				  GWEN_DB_NODE *data,
 				  GWEN_DB_NODE *cfg,
-				  uint32_t flags,
-				  uint32_t guiid,
-				  int msecs);
+				  uint32_t flags);
 
 static int GWEN_DBIO_OldDb_Import(GWEN_DBIO *dbio,
-				  GWEN_IO_LAYER *io,
+				  GWEN_SYNCIO *sio,
 				  GWEN_DB_NODE *data,
 				  GWEN_DB_NODE *cfg,
-				  uint32_t flags,
-				  uint32_t guiid,
-				  int msecs);
+				  uint32_t flags);
 
-static GWEN_DBIO_CHECKFILE_RESULT GWEN_DBIO_OldDb_CheckFile(GWEN_DBIO *dbio,
-							    const char *fname,
-							    uint32_t guiid,
-							    int msecs);
+static GWEN_DBIO_CHECKFILE_RESULT GWEN_DBIO_OldDb_CheckFile(GWEN_DBIO *dbio, const char *fname);
 
 
 
