@@ -38,10 +38,11 @@
 GWEN_BUFFER *GWEN_Buffer_new(char *buffer,
                              uint32_t size,
                              uint32_t used,
-                             int take){
+                             int take) {
   GWEN_BUFFER *bf;
 
   GWEN_NEW_OBJECT(GWEN_BUFFER, bf);
+  bf->_refCount=1;
   if (!buffer) {
     /* allocate buffer */
     bf->realPtr=(char*)GWEN_Memory_malloc(size+1);
@@ -72,15 +73,27 @@ GWEN_BUFFER *GWEN_Buffer_new(char *buffer,
 
 
 
-void GWEN_Buffer_free(GWEN_BUFFER *bf){
+void GWEN_Buffer_Attach(GWEN_BUFFER *bf) {
+  assert(bf->_refCount);
+  bf->_refCount++;
+}
+
+
+
+void GWEN_Buffer_free(GWEN_BUFFER *bf) {
   if (bf) {
-    if (bf->flags & GWEN_BUFFER_FLAGS_OWNED)
-      GWEN_Memory_dealloc(bf->realPtr);
-    if (bf->syncIo) {
-      if (bf->flags & GWEN_BUFFER_FLAGS_OWN_SYNCIO)
-        GWEN_SyncIo_free(bf->syncIo);
+    assert(bf->_refCount);
+    if (bf->_refCount==1) {
+      if (bf->flags & GWEN_BUFFER_FLAGS_OWNED)
+        GWEN_Memory_dealloc(bf->realPtr);
+      if (bf->syncIo) {
+        if (bf->flags & GWEN_BUFFER_FLAGS_OWN_SYNCIO)
+          GWEN_SyncIo_free(bf->syncIo);
+      }
+      GWEN_FREE_OBJECT(bf);
     }
-    GWEN_FREE_OBJECT(bf);
+    else
+      bf->_refCount--;
   }
 }
 
@@ -91,6 +104,8 @@ GWEN_BUFFER *GWEN_Buffer_dup(GWEN_BUFFER *bf) {
   uint32_t i;
 
   GWEN_NEW_OBJECT(GWEN_BUFFER, newbf);
+  newbf->_refCount=1;
+
   if (bf->realPtr && bf->realBufferSize) {
     newbf->realPtr=(char*)GWEN_Memory_malloc(bf->realBufferSize);
     newbf->ptr=newbf->realPtr+(bf->ptr-bf->realPtr);
@@ -134,7 +149,7 @@ int GWEN_Buffer_Relinquish(GWEN_BUFFER *bf) {
 
 
 
-int GWEN_Buffer_ReserveBytes(GWEN_BUFFER *bf, uint32_t res){
+int GWEN_Buffer_ReserveBytes(GWEN_BUFFER *bf, uint32_t res) {
   assert(bf);
   if (!res)
     return 0;
@@ -164,40 +179,40 @@ int GWEN_Buffer_ReserveBytes(GWEN_BUFFER *bf, uint32_t res){
 
 
 
-uint32_t GWEN_Buffer_GetMode(GWEN_BUFFER *bf){
+uint32_t GWEN_Buffer_GetMode(GWEN_BUFFER *bf) {
   assert(bf);
   return bf->mode;
 }
 
 
 
-void GWEN_Buffer_SetMode(GWEN_BUFFER *bf, uint32_t mode){
+void GWEN_Buffer_SetMode(GWEN_BUFFER *bf, uint32_t mode) {
   assert(bf);
   bf->mode=mode;
 }
 
 
-void GWEN_Buffer_AddMode(GWEN_BUFFER *bf, uint32_t mode){
+void GWEN_Buffer_AddMode(GWEN_BUFFER *bf, uint32_t mode) {
   assert(bf);
   bf->mode|=mode;
 }
 
 
-void GWEN_Buffer_SubMode(GWEN_BUFFER *bf, uint32_t mode){
+void GWEN_Buffer_SubMode(GWEN_BUFFER *bf, uint32_t mode) {
   assert(bf);
   bf->mode&=~mode;
 }
 
 
 
-uint32_t GWEN_Buffer_GetHardLimit(GWEN_BUFFER *bf){
+uint32_t GWEN_Buffer_GetHardLimit(GWEN_BUFFER *bf) {
   assert(bf);
   return bf->hardLimit;
 }
 
 
 
-void GWEN_Buffer_SetHardLimit(GWEN_BUFFER *bf, uint32_t l){
+void GWEN_Buffer_SetHardLimit(GWEN_BUFFER *bf, uint32_t l) {
   assert(bf);
   assert(l);
   bf->hardLimit=l;
@@ -205,14 +220,14 @@ void GWEN_Buffer_SetHardLimit(GWEN_BUFFER *bf, uint32_t l){
 
 
 
-char *GWEN_Buffer_GetStart(const GWEN_BUFFER *bf){
+char *GWEN_Buffer_GetStart(const GWEN_BUFFER *bf) {
   assert(bf);
   return bf->ptr;
 }
 
 
 
-uint32_t GWEN_Buffer_GetSize(const GWEN_BUFFER *bf){
+uint32_t GWEN_Buffer_GetSize(const GWEN_BUFFER *bf) {
   assert(bf);
   if (bf->mode & GWEN_BUFFER_MODE_DYNAMIC)
     return bf->hardLimit;
@@ -221,14 +236,14 @@ uint32_t GWEN_Buffer_GetSize(const GWEN_BUFFER *bf){
 
 
 
-uint32_t GWEN_Buffer_GetPos(const GWEN_BUFFER *bf){
+uint32_t GWEN_Buffer_GetPos(const GWEN_BUFFER *bf) {
   assert(bf);
   return bf->pos;
 }
 
 
 
-int GWEN_Buffer_SetPos(GWEN_BUFFER *bf, uint32_t i){
+int GWEN_Buffer_SetPos(GWEN_BUFFER *bf, uint32_t i) {
   assert(bf);
 
   if (i>=bf->bufferSize) {
@@ -248,7 +263,7 @@ int GWEN_Buffer_SetPos(GWEN_BUFFER *bf, uint32_t i){
 
 
 
-uint32_t GWEN_Buffer_GetUsedBytes(const GWEN_BUFFER *bf){
+uint32_t GWEN_Buffer_GetUsedBytes(const GWEN_BUFFER *bf) {
   assert(bf);
   return bf->bytesUsed;
 }
@@ -261,11 +276,10 @@ int GWEN_Buffer_AllocRoom(GWEN_BUFFER *bf, uint32_t size) {
     DBG_ERROR(GWEN_LOGDOMAIN, "Read-only mode");
     if (bf->mode & GWEN_BUFFER_MODE_ABORT_ON_MEMFULL) {
       abort();
-      return GWEN_ERROR_PERMISSIONS;
     }
+    return GWEN_ERROR_PERMISSIONS;
   }
   /*DBG_VERBOUS(GWEN_LOGDOMAIN, "Allocating %d bytes", size);*/
-  /*if (bf->pos+size>bf->bufferSize) {*/
   if (bf->bytesUsed+(size+1) > bf->bufferSize) {
     /* need to realloc */
     uint32_t nsize;
@@ -284,8 +298,8 @@ int GWEN_Buffer_AllocRoom(GWEN_BUFFER *bf, uint32_t size) {
 
     /* calculate reserved bytes (to set ptr later) */
     reserved=bf->ptr-bf->realPtr;
-    /* this is the raw number of bytes we need */
-    /*nsize=bf->pos+size-bf->bufferSize;*/
+    /* this is the raw number of bytes we need (we always add a NULL
+     * character) */
     nsize=bf->bytesUsed+(size+1)-bf->bufferSize;
     /* round it up */
     nsize=(nsize+(bf->step-1));
@@ -305,17 +319,16 @@ int GWEN_Buffer_AllocRoom(GWEN_BUFFER *bf, uint32_t size) {
     }
     DBG_VERBOUS(GWEN_LOGDOMAIN, "Reallocating from %d to %d bytes",
                 bf->bufferSize, nsize);
-    /* we always add a NULL character */
     if (bf->realPtr==NULL) {
-      p=GWEN_Memory_malloc(nsize+1);
+      p=GWEN_Memory_malloc(nsize);
     }
     else {
-      p=GWEN_Memory_realloc(bf->realPtr, nsize+1);
+      p=GWEN_Memory_realloc(bf->realPtr, nsize);
     }
     if (!p) {
       DBG_ERROR(GWEN_LOGDOMAIN, "Realloc failed.");
       if (bf->mode & GWEN_BUFFER_MODE_ABORT_ON_MEMFULL) {
-	abort();
+        abort();
       }
       return GWEN_ERROR_MEMORY_FULL;
     }
@@ -334,7 +347,7 @@ int GWEN_Buffer_AllocRoom(GWEN_BUFFER *bf, uint32_t size) {
 
 int GWEN_Buffer_AppendBytes(GWEN_BUFFER *bf,
                             const char *buffer,
-                            uint32_t size){
+                            uint32_t size) {
   int rv;
 
   assert(bf);
@@ -343,26 +356,17 @@ int GWEN_Buffer_AppendBytes(GWEN_BUFFER *bf,
     DBG_ERROR(GWEN_LOGDOMAIN, "Read-only mode");
     if (bf->mode & GWEN_BUFFER_MODE_ABORT_ON_MEMFULL) {
       abort();
-      return GWEN_ERROR_PERMISSIONS;
     }
+    return GWEN_ERROR_PERMISSIONS;
   }
 
-  rv=GWEN_Buffer_AllocRoom(bf, size+1);
+  rv=GWEN_Buffer_AllocRoom(bf, size);
   if (rv<0) {
     DBG_DEBUG(GWEN_LOGDOMAIN, "called from here");
     return rv;
   }
-  /* if (bf->pos+size>bf->bufferSize) { */
-  if (bf->bytesUsed+size>bf->bufferSize) {
-    DBG_ERROR(GWEN_LOGDOMAIN, "Buffer full (%d [%d] of %d bytes)",
-              /*bf->pos, size,*/
-              bf->bytesUsed, size+1,
-              bf->bufferSize);
-    return GWEN_ERROR_BUFFER_OVERFLOW;
-  }
 
   memmove(bf->ptr+bf->bytesUsed, buffer, size);
-  /*bf->pos+=size;*/
   if (bf->pos==bf->bytesUsed)
     bf->pos+=size;
   bf->bytesUsed+=size;
@@ -373,7 +377,7 @@ int GWEN_Buffer_AppendBytes(GWEN_BUFFER *bf,
 
 
 
-int GWEN_Buffer_AppendByte(GWEN_BUFFER *bf, char c){
+int GWEN_Buffer_AppendByte(GWEN_BUFFER *bf, char c) {
   int rv;
 
   assert(bf);
@@ -382,8 +386,8 @@ int GWEN_Buffer_AppendByte(GWEN_BUFFER *bf, char c){
     DBG_ERROR(GWEN_LOGDOMAIN, "Read-only mode");
     if (bf->mode & GWEN_BUFFER_MODE_ABORT_ON_MEMFULL) {
       abort();
-      return GWEN_ERROR_PERMISSIONS;
     }
+    return GWEN_ERROR_PERMISSIONS;
   }
 
   if (bf->bytesUsed+1+1 > bf->bufferSize) {
@@ -404,7 +408,7 @@ int GWEN_Buffer_AppendByte(GWEN_BUFFER *bf, char c){
 
 
 
-int GWEN_Buffer__FillBuffer_SyncIo(GWEN_BUFFER *bf){
+int GWEN_Buffer__FillBuffer_SyncIo(GWEN_BUFFER *bf) {
   if (bf->syncIo) {
     uint32_t toread;
     int rv;
@@ -415,8 +419,8 @@ int GWEN_Buffer__FillBuffer_SyncIo(GWEN_BUFFER *bf){
       return GWEN_ERROR_GENERIC;
     }
     rv=GWEN_SyncIo_ReadForced(bf->syncIo,
-			      (uint8_t*) (bf->ptr+bf->bytesUsed),
-			      toread);
+                              (uint8_t*) (bf->ptr+bf->bytesUsed),
+                              toread);
     if (rv<0) {
       DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
       return rv;
@@ -430,8 +434,8 @@ int GWEN_Buffer__FillBuffer_SyncIo(GWEN_BUFFER *bf){
   }
   else {
     DBG_DEBUG(GWEN_LOGDOMAIN,
-	      "End of used area reached and no SYNCIO (%d bytes)",
-	      bf->pos);
+              "End of used area reached and no SYNCIO (%d bytes)",
+              bf->pos);
     return GWEN_ERROR_EOF;
   }
   return 0;
@@ -439,20 +443,20 @@ int GWEN_Buffer__FillBuffer_SyncIo(GWEN_BUFFER *bf){
 
 
 
-int GWEN_Buffer__FillBuffer(GWEN_BUFFER *bf){
+int GWEN_Buffer__FillBuffer(GWEN_BUFFER *bf) {
   assert(bf);
   if (bf->mode & GWEN_BUFFER_MODE_USE_SYNCIO)
     return GWEN_Buffer__FillBuffer_SyncIo(bf);
   else {
     DBG_DEBUG(GWEN_LOGDOMAIN,
-	      "End of used area reached (%d bytes)", bf->pos);
+              "End of used area reached (%d bytes)", bf->pos);
     return GWEN_ERROR_EOF;
   }
 }
 
 
 
-int GWEN_Buffer_PeekByte(GWEN_BUFFER *bf){
+int GWEN_Buffer_PeekByte(GWEN_BUFFER *bf) {
   assert(bf);
 
   if (bf->pos>=bf->bytesUsed) {
@@ -470,7 +474,7 @@ int GWEN_Buffer_PeekByte(GWEN_BUFFER *bf){
 
 
 
-int GWEN_Buffer_ReadByte(GWEN_BUFFER *bf){
+int GWEN_Buffer_ReadByte(GWEN_BUFFER *bf) {
   assert(bf);
 
   if (bf->pos>=bf->bytesUsed) {
@@ -488,7 +492,7 @@ int GWEN_Buffer_ReadByte(GWEN_BUFFER *bf){
 
 
 
-int GWEN_Buffer_IncrementPos(GWEN_BUFFER *bf, uint32_t i){
+int GWEN_Buffer_IncrementPos(GWEN_BUFFER *bf, uint32_t i) {
   assert(bf);
 
   if (i+bf->pos>=bf->bufferSize) {
@@ -496,7 +500,7 @@ int GWEN_Buffer_IncrementPos(GWEN_BUFFER *bf, uint32_t i){
       DBG_DEBUG(GWEN_LOGDOMAIN,
                 "Position %d outside buffer boundaries (%d bytes)\n"
                 "Incrementing anyway",
-		i+bf->pos, bf->bufferSize);
+                i+bf->pos, bf->bufferSize);
     }
   }
 
@@ -506,12 +510,12 @@ int GWEN_Buffer_IncrementPos(GWEN_BUFFER *bf, uint32_t i){
 
 
 
-int GWEN_Buffer_AdjustUsedBytes(GWEN_BUFFER *bf){
+int GWEN_Buffer_AdjustUsedBytes(GWEN_BUFFER *bf) {
   assert(bf);
   if (bf->pos<=bf->bufferSize) {
     if (bf->pos>bf->bytesUsed) {
       DBG_DEBUG(GWEN_LOGDOMAIN, "Adjusted buffer (uses now %d bytes)",
-               bf->pos);
+                bf->pos);
       bf->bytesUsed=bf->pos;
     }
     /* append a NULL to allow using the buffer as ASCIIZ string */
@@ -527,7 +531,7 @@ int GWEN_Buffer_AdjustUsedBytes(GWEN_BUFFER *bf){
 
 
 
-int GWEN_Buffer_DecrementPos(GWEN_BUFFER *bf, uint32_t i){
+int GWEN_Buffer_DecrementPos(GWEN_BUFFER *bf, uint32_t i) {
   assert(bf);
 
   if (bf->pos<i) {
@@ -542,7 +546,7 @@ int GWEN_Buffer_DecrementPos(GWEN_BUFFER *bf, uint32_t i){
 
 
 
-int GWEN_Buffer_AppendBuffer(GWEN_BUFFER *bf, GWEN_BUFFER *sf){
+int GWEN_Buffer_AppendBuffer(GWEN_BUFFER *bf, GWEN_BUFFER *sf) {
 
   assert(bf);
   assert(sf);
@@ -551,8 +555,8 @@ int GWEN_Buffer_AppendBuffer(GWEN_BUFFER *bf, GWEN_BUFFER *sf){
     DBG_ERROR(GWEN_LOGDOMAIN, "Read-only mode");
     if (bf->mode & GWEN_BUFFER_MODE_ABORT_ON_MEMFULL) {
       abort();
-      return GWEN_ERROR_PERMISSIONS;
     }
+    return GWEN_ERROR_PERMISSIONS;
   }
 
   if (sf->bytesUsed)
@@ -562,7 +566,7 @@ int GWEN_Buffer_AppendBuffer(GWEN_BUFFER *bf, GWEN_BUFFER *sf){
 
 
 
-uint32_t GWEN_Buffer_GetMaxUnsegmentedWrite(GWEN_BUFFER *bf){
+uint32_t GWEN_Buffer_GetMaxUnsegmentedWrite(GWEN_BUFFER *bf) {
   assert(bf);
 
   return (bf->bufferSize-bf->bytesUsed);
@@ -570,7 +574,7 @@ uint32_t GWEN_Buffer_GetMaxUnsegmentedWrite(GWEN_BUFFER *bf){
 
 
 
-uint32_t GWEN_Buffer_GetBytesLeft(GWEN_BUFFER *bf){
+uint32_t GWEN_Buffer_GetBytesLeft(GWEN_BUFFER *bf) {
   assert(bf);
 
   if (bf->pos<bf->bytesUsed)
@@ -581,14 +585,23 @@ uint32_t GWEN_Buffer_GetBytesLeft(GWEN_BUFFER *bf){
 
 
 
-char *GWEN_Buffer_GetPosPointer(const GWEN_BUFFER *bf){
+char *GWEN_Buffer_GetPosPointer(const GWEN_BUFFER *bf) {
   assert(bf);
   return bf->ptr+bf->pos;
 }
 
 
 
-uint32_t GWEN_Buffer_GetBookmark(const GWEN_BUFFER *bf, unsigned int idx){
+void GWEN_Buffer_OverwriteContent(GWEN_BUFFER *bf, int c) {
+  assert(bf);
+  if (bf->realPtr && bf->realBufferSize) {
+    memset(bf->realPtr, c, bf->realBufferSize);
+  }
+}
+
+
+
+uint32_t GWEN_Buffer_GetBookmark(const GWEN_BUFFER *bf, unsigned int idx) {
   assert(bf);
   assert(idx<GWEN_BUFFER_MAX_BOOKMARKS);
   return bf->bookmarks[idx];
@@ -597,7 +610,7 @@ uint32_t GWEN_Buffer_GetBookmark(const GWEN_BUFFER *bf, unsigned int idx){
 
 
 void GWEN_Buffer_SetBookmark(GWEN_BUFFER *bf, unsigned int idx,
-                             uint32_t v){
+                             uint32_t v) {
   assert(bf);
   assert(idx<GWEN_BUFFER_MAX_BOOKMARKS);
   bf->bookmarks[idx]=v;
@@ -668,7 +681,7 @@ void GWEN_Buffer_Dump(GWEN_BUFFER *bf, unsigned int insert) {
 
 
 
-void GWEN_Buffer_Reset(GWEN_BUFFER *bf){
+void GWEN_Buffer_Reset(GWEN_BUFFER *bf) {
   assert(bf);
   bf->pos=0;
   bf->bytesUsed=0;
@@ -677,14 +690,14 @@ void GWEN_Buffer_Reset(GWEN_BUFFER *bf){
 
 
 
-void GWEN_Buffer_Rewind(GWEN_BUFFER *bf){
+void GWEN_Buffer_Rewind(GWEN_BUFFER *bf) {
   assert(bf);
   bf->pos=0;
 }
 
 
 
-int GWEN_Buffer_ReadBytes(GWEN_BUFFER *bf, char *buffer, uint32_t *size){
+int GWEN_Buffer_ReadBytes(GWEN_BUFFER *bf, char *buffer, uint32_t *size) {
   /* optimized for speed */
   uint32_t i;
   char *pdst;
@@ -724,14 +737,14 @@ int GWEN_Buffer_ReadBytes(GWEN_BUFFER *bf, char *buffer, uint32_t *size){
 
 
 
-uint32_t GWEN_Buffer_GetStep(GWEN_BUFFER *bf){
+uint32_t GWEN_Buffer_GetStep(GWEN_BUFFER *bf) {
   assert(bf);
   return bf->step;
 }
 
 
 
-void GWEN_Buffer_SetStep(GWEN_BUFFER *bf, uint32_t step){
+void GWEN_Buffer_SetStep(GWEN_BUFFER *bf, uint32_t step) {
   assert(bf);
   bf->step=step;
 }
@@ -753,7 +766,7 @@ void GWEN_Buffer_AdjustBookmarks(GWEN_BUFFER *bf,
 
 
 int GWEN_Buffer_InsertRoom(GWEN_BUFFER *bf,
-                           uint32_t size){
+                           uint32_t size) {
   char *p;
   int i;
   int rv;
@@ -764,8 +777,8 @@ int GWEN_Buffer_InsertRoom(GWEN_BUFFER *bf,
     DBG_ERROR(GWEN_LOGDOMAIN, "Read-only mode");
     if (bf->mode & GWEN_BUFFER_MODE_ABORT_ON_MEMFULL) {
       abort();
-      return GWEN_ERROR_PERMISSIONS;
     }
+    return GWEN_ERROR_PERMISSIONS;
   }
 
   if (bf->pos==0) {
@@ -798,12 +811,7 @@ int GWEN_Buffer_InsertRoom(GWEN_BUFFER *bf,
     DBG_DEBUG(GWEN_LOGDOMAIN, "called from here");
     return rv;
   }
-  if (bf->pos+size>bf->bufferSize) {
-    DBG_ERROR(GWEN_LOGDOMAIN, "Buffer full (%d [%d] of %d bytes)",
-	      bf->pos, size,
-	      bf->bufferSize);
-    return GWEN_ERROR_BUFFER_OVERFLOW;
-  }
+  assert(bf->pos<=bf->bytesUsed);
   p=bf->ptr+bf->pos;
   i=bf->bytesUsed-bf->pos;
   if (i>0)
@@ -818,7 +826,7 @@ int GWEN_Buffer_InsertRoom(GWEN_BUFFER *bf,
 
 
 
-int GWEN_Buffer_RemoveRoom(GWEN_BUFFER *bf, uint32_t size){
+int GWEN_Buffer_RemoveRoom(GWEN_BUFFER *bf, uint32_t size) {
   char *p;
   int i;
 
@@ -828,31 +836,27 @@ int GWEN_Buffer_RemoveRoom(GWEN_BUFFER *bf, uint32_t size){
     DBG_ERROR(GWEN_LOGDOMAIN, "Read-only mode");
     if (bf->mode & GWEN_BUFFER_MODE_ABORT_ON_MEMFULL) {
       abort();
-      return GWEN_ERROR_PERMISSIONS;
     }
+    return GWEN_ERROR_PERMISSIONS;
+  }
+
+  if (bf->bytesUsed<size+bf->pos) {
+    /* can't remove more bytes than we have */
+    return GWEN_ERROR_INVALID;
   }
 
   if (bf->pos==0) {
-    if (bf->bytesUsed<size) {
-      /* can't remove bytes we don't have */
-      return GWEN_ERROR_INVALID;
-    }
     /* simply add to reserved space */
     bf->ptr+=size;
     bf->bytesUsed-=size;
     bf->bufferSize-=size;
   }
   else {
-    if (bf->bytesUsed+size<(bf->bytesUsed)) {
-      /* can't remove more bytes than we have */
-      return GWEN_ERROR_INVALID;
-    }
-
     /* we need to get the rest closer */
     p=bf->ptr+bf->pos+size;
     i=bf->bytesUsed-bf->pos-size;
     memmove(bf->ptr+bf->pos, p, i);
-    bf->bytesUsed+=size;
+    bf->bytesUsed-=size;
   }
 
   /* append "0" behind buffer */
@@ -865,9 +869,9 @@ int GWEN_Buffer_RemoveRoom(GWEN_BUFFER *bf, uint32_t size){
 
 
 int GWEN_Buffer_ReplaceBytes(GWEN_BUFFER *bf,
-			     uint32_t rsize,
-			     const char *buffer,
-			     uint32_t size){
+                             uint32_t rsize,
+                             const char *buffer,
+                             uint32_t size) {
   int32_t d;
   int rv;
 
@@ -875,8 +879,8 @@ int GWEN_Buffer_ReplaceBytes(GWEN_BUFFER *bf,
     DBG_ERROR(GWEN_LOGDOMAIN, "Read-only mode");
     if (bf->mode & GWEN_BUFFER_MODE_ABORT_ON_MEMFULL) {
       abort();
-      return GWEN_ERROR_PERMISSIONS;
     }
+    return GWEN_ERROR_PERMISSIONS;
   }
 
   /* either insert or remove bytes */
@@ -892,8 +896,8 @@ int GWEN_Buffer_ReplaceBytes(GWEN_BUFFER *bf,
     rv=0;
   if (rv) {
     DBG_ERROR(GWEN_LOGDOMAIN,
-	      "Error replacing %d bytes with %d bytes (%d)",
-	      rsize, size, rv);
+              "Error replacing %d bytes with %d bytes (%d)",
+              rsize, size, rv);
     return rv;
   }
 
@@ -907,7 +911,7 @@ int GWEN_Buffer_ReplaceBytes(GWEN_BUFFER *bf,
 
 int GWEN_Buffer_InsertBytes(GWEN_BUFFER *bf,
                             const char *buffer,
-                            uint32_t size){
+                            uint32_t size) {
   int rv;
 
   assert(bf);
@@ -917,8 +921,8 @@ int GWEN_Buffer_InsertBytes(GWEN_BUFFER *bf,
     DBG_ERROR(GWEN_LOGDOMAIN, "Read-only mode");
     if (bf->mode & GWEN_BUFFER_MODE_ABORT_ON_MEMFULL) {
       abort();
-      return GWEN_ERROR_PERMISSIONS;
     }
+    return GWEN_ERROR_PERMISSIONS;
   }
 
   rv=GWEN_Buffer_InsertRoom(bf, size);
@@ -932,7 +936,7 @@ int GWEN_Buffer_InsertBytes(GWEN_BUFFER *bf,
 
 
 
-int GWEN_Buffer_InsertByte(GWEN_BUFFER *bf, char c){
+int GWEN_Buffer_InsertByte(GWEN_BUFFER *bf, char c) {
   int rv;
 
   assert(bf);
@@ -941,8 +945,8 @@ int GWEN_Buffer_InsertByte(GWEN_BUFFER *bf, char c){
     DBG_ERROR(GWEN_LOGDOMAIN, "Read-only mode");
     if (bf->mode & GWEN_BUFFER_MODE_ABORT_ON_MEMFULL) {
       abort();
-      return GWEN_ERROR_PERMISSIONS;
     }
+    return GWEN_ERROR_PERMISSIONS;
   }
 
   rv=GWEN_Buffer_InsertRoom(bf, 1);
@@ -957,7 +961,7 @@ int GWEN_Buffer_InsertByte(GWEN_BUFFER *bf, char c){
 
 
 int GWEN_Buffer_InsertBuffer(GWEN_BUFFER *bf,
-                             GWEN_BUFFER *sf){
+                             GWEN_BUFFER *sf) {
   assert(bf);
   assert(sf);
 
@@ -969,33 +973,38 @@ int GWEN_Buffer_InsertBuffer(GWEN_BUFFER *bf,
 int GWEN_Buffer_Crop(GWEN_BUFFER *bf,
                      uint32_t pos,
                      uint32_t l) {
+  int offset;
 
   if (bf->mode & GWEN_BUFFER_MODE_READONLY) {
     DBG_ERROR(GWEN_LOGDOMAIN, "Read-only mode");
     if (bf->mode & GWEN_BUFFER_MODE_ABORT_ON_MEMFULL) {
       abort();
-      return GWEN_ERROR_PERMISSIONS;
     }
+    return GWEN_ERROR_PERMISSIONS;
   }
 
   if (pos>=bf->bufferSize) {
     DBG_ERROR(GWEN_LOGDOMAIN, "Position outside buffer");
     return -1;
   }
-  bf->ptr+=pos;
-  bf->bufferSize-=pos;
-  bf->pos-=pos;
   if (bf->bytesUsed-pos<l) {
     DBG_INFO(GWEN_LOGDOMAIN, "Invalid length");
     return -1;
   }
+  bf->ptr+=pos;
+  bf->bufferSize-=pos;
+  if (bf->pos>pos)
+    offset=pos;
+  else
+    offset=bf->pos;
+  bf->pos-=offset;
   bf->bytesUsed=l;
-  GWEN_Buffer_AdjustBookmarks(bf, pos, -pos);
   /* adjust position after possible truncation */
   if (bf->pos>bf->bytesUsed)
-      bf->pos=bf->bytesUsed;
+    bf->pos=bf->bytesUsed;
 
   bf->ptr[bf->bytesUsed]=0;
+  GWEN_Buffer_AdjustBookmarks(bf, offset, -offset);
 
   return 0;
 }
@@ -1003,7 +1012,7 @@ int GWEN_Buffer_Crop(GWEN_BUFFER *bf,
 
 
 int GWEN_Buffer_AppendString(GWEN_BUFFER *bf,
-                             const char *buffer){
+                             const char *buffer) {
   assert(bf);
   assert(buffer);
   return GWEN_Buffer_AppendBytes(bf, buffer, strlen(buffer));
@@ -1012,7 +1021,7 @@ int GWEN_Buffer_AppendString(GWEN_BUFFER *bf,
 
 
 int GWEN_Buffer_InsertString(GWEN_BUFFER *bf,
-                             const char *buffer){
+                             const char *buffer) {
   assert(bf);
   assert(buffer);
   return GWEN_Buffer_InsertBytes(bf, buffer, strlen(buffer));
@@ -1021,8 +1030,8 @@ int GWEN_Buffer_InsertString(GWEN_BUFFER *bf,
 
 
 void GWEN_Buffer_SetSourceSyncIo(GWEN_BUFFER *bf,
-				 GWEN_SYNCIO *sio,
-				 int take) {
+                                 GWEN_SYNCIO *sio,
+                                 int take) {
   assert(bf);
   if (bf->syncIo) {
     if (bf->flags & GWEN_BUFFER_FLAGS_OWN_SYNCIO) {
@@ -1040,7 +1049,7 @@ void GWEN_Buffer_SetSourceSyncIo(GWEN_BUFFER *bf,
 
 int GWEN_Buffer_FillWithBytes(GWEN_BUFFER *bf,
                               unsigned char c,
-                              uint32_t size){
+                              uint32_t size) {
   int rv;
 
   assert(bf);
@@ -1049,8 +1058,8 @@ int GWEN_Buffer_FillWithBytes(GWEN_BUFFER *bf,
     DBG_ERROR(GWEN_LOGDOMAIN, "Read-only mode");
     if (bf->mode & GWEN_BUFFER_MODE_ABORT_ON_MEMFULL) {
       abort();
-      return GWEN_ERROR_PERMISSIONS;
     }
+    return GWEN_ERROR_PERMISSIONS;
   }
 
   rv=GWEN_Buffer_AllocRoom(bf, size+1);
@@ -1058,13 +1067,6 @@ int GWEN_Buffer_FillWithBytes(GWEN_BUFFER *bf,
     DBG_DEBUG(GWEN_LOGDOMAIN, "called from here");
     return rv;
   }
-  /* if (bf->pos+size>bf->bufferSize) { */
-  if (bf->bytesUsed+size>bf->bufferSize) {
-    DBG_ERROR(GWEN_LOGDOMAIN, "Buffer full (%d [%d] of %d bytes)",
-              bf->bytesUsed, size+1,
-              bf->bufferSize);
-    return GWEN_ERROR_BUFFER_OVERFLOW;
-  }
   memset(bf->ptr+bf->bytesUsed, c, size);
   if (bf->pos==bf->bytesUsed)
     bf->pos+=size;
@@ -1078,7 +1080,7 @@ int GWEN_Buffer_FillWithBytes(GWEN_BUFFER *bf,
 
 int GWEN_Buffer_FillLeftWithBytes(GWEN_BUFFER *bf,
                                   unsigned char c,
-                                  uint32_t size){
+                                  uint32_t size) {
   int rv;
 
   assert(bf);
@@ -1087,8 +1089,8 @@ int GWEN_Buffer_FillLeftWithBytes(GWEN_BUFFER *bf,
     DBG_ERROR(GWEN_LOGDOMAIN, "Read-only mode");
     if (bf->mode & GWEN_BUFFER_MODE_ABORT_ON_MEMFULL) {
       abort();
-      return GWEN_ERROR_PERMISSIONS;
     }
+    return GWEN_ERROR_PERMISSIONS;
   }
 
   rv=GWEN_Buffer_InsertRoom(bf, size);
@@ -1102,6 +1104,17 @@ int GWEN_Buffer_FillLeftWithBytes(GWEN_BUFFER *bf,
 
 
 
+int GWENHYWFAR_CB GWEN_Buffer_CacheFn_Attach(void *ptr) {
+  GWEN_Buffer_Attach((GWEN_BUFFER*) ptr);
+  return 0;
+}
+
+
+
+int GWENHYWFAR_CB GWEN_Buffer_CacheFn_Free(void *ptr) {
+  GWEN_Buffer_free((GWEN_BUFFER*) ptr);
+  return 0;
+}
 
 
 
