@@ -134,7 +134,7 @@ extern "C" {
  * aware that this can cause problems once one of your users tries
  * to compile this with a different compiler. Therefore these code
  * lines should end directly with the closing parentheses.</p>
- * 
+ *
  * <p>
  * The list management code assumes that there is a function called
  * (in this example) @b MyStruct_free() (or generally: TYPEPREFIX_free).
@@ -158,7 +158,7 @@ typedef struct GWEN_TREE_ELEMENT GWEN_TREE_ELEMENT;
 
 /** Allocate (create) a new empty list. */
 GWENHYWFAR_API
-GWEN_TREE *GWEN_Tree_new();
+GWEN_TREE *GWEN_Tree_new(void);
 
 /** Free (delete) an existing list.  The list elements are
  * untouched by this function; they need to be freed
@@ -316,7 +316,7 @@ GWEN_TREE_ELEMENT *_tree_element;
   \
   decl int pr##_Tree_HasChildElement(const t *who, const t *element); \
   decl void pr##_Tree_ClearChildren(t *element); \
-
+ 
 
 #define GWEN_TREE_FUNCTION_DEFS_CONST(t, pr) \
   GWEN_TREE_FUNCTION_LIB_DEFS_CONST(t, pr, GWEN_DUMMY_EMPTY_ARG)
@@ -385,11 +385,11 @@ GWEN_TREE_ELEMENT *_tree_element;
   GWEN_TREE_FUNCTION_LIB_DEFS(t, pr, GWEN_DUMMY_EMPTY_ARG)
 
 
-  /**
-   * Use this inside your code files (*.c).
-   * Actually implements the functions for which the prototypes have been
-   * defined via @ref GWEN_TREE_FUNCTION_DEFS.
-   */
+/**
+ * Use this inside your code files (*.c).
+ * Actually implements the functions for which the prototypes have been
+ * defined via @ref GWEN_TREE_FUNCTION_DEFS.
+ */
 #define GWEN_TREE_FUNCTIONS(t, pr) \
   \
   void pr##_Tree_Add(t##_TREE *l, t *element) { \
@@ -535,7 +535,7 @@ GWEN_TREE_ELEMENT *_tree_element;
     return (t*)GWEN_TreeElement_GetParent(element->_tree_element);\
   } \
   \
-
+ 
 
 /**
  * Use this in your code file (*.c) inside the init code for the struct
