@@ -58,7 +58,7 @@ static void dumpKeyData(gcry_ac_data_t data) {
 
 
 
-int GWEN_Crypt_KeyRsa__getNamedElement(gcry_sexp_t pkey, const char *name, gcry_mpi_t *pMpi) {
+static int GWEN_Crypt_KeyRsa__getNamedElement(gcry_sexp_t pkey, const char *name, gcry_mpi_t *pMpi) {
   gcry_sexp_t list;
   gcry_mpi_t mpi;
 
@@ -84,41 +84,40 @@ int GWEN_Crypt_KeyRsa__getNamedElement(gcry_sexp_t pkey, const char *name, gcry_
 
 
 
-int GWEN_Crypt_KeyRsa_GeneratePair2(unsigned int nbits, int use65537e,
-				    GWEN_CRYPT_KEY **pPubKey,
-				    GWEN_CRYPT_KEY **pSecretKey) {
+int GWEN_Crypt_KeyRsa_GeneratePair(unsigned int nbytes, int use65537e,
+                                   GWEN_CRYPT_KEY **pPubKey,
+                                   GWEN_CRYPT_KEY **pSecretKey) {
   gcry_sexp_t keyparm, key;
   int rc;
   char buffer[256];
   char numbuf[32];
   gcry_sexp_t pkey;
-  int nbytes;
+  int nbits;
   GWEN_CRYPT_KEY *pubKey=NULL;
   GWEN_CRYPT_KEY *secretKey=NULL;
 
-  nbytes=nbits/8;
-  if (nbits%8)
-    nbytes++;
+  nbits=nbytes*8;
+  assert(nbits>0);
   snprintf(numbuf, sizeof(numbuf)-1, "%d", nbits);
   if (use65537e) {
     snprintf(buffer, sizeof(buffer)-1,
-	     "(genkey\n"
-	     " (rsa\n"
-	     "  (nbits %zd:%d)\n"
-	     "  (rsa-use-e 5:65537)\n"
-	     " ))",
-	     strlen(numbuf),
-	     nbits);
+             "(genkey\n"
+             " (rsa\n"
+             "  (nbits %zd:%d)\n"
+             "  (rsa-use-e 5:65537)\n"
+             " ))",
+             strlen(numbuf),
+             nbits);
   }
   else
     snprintf(buffer, sizeof(buffer)-1,
-	     "(genkey\n"
-	     " (rsa\n"
-	     "  (nbits %zd:%d)\n"
-	     "  (rsa-use-e 1:0)\n"
-	     " ))",
-	     strlen(numbuf),
-	     nbits);
+             "(genkey\n"
+             " (rsa\n"
+             "  (nbits %zd:%d)\n"
+             "  (rsa-use-e 1:0)\n"
+             " ))",
+             strlen(numbuf),
+             nbits);
   buffer[sizeof(buffer)-1]=0;
 
   /*DBG_ERROR(0, "Genkey string: [%s]", buffer);*/
@@ -126,7 +125,7 @@ int GWEN_Crypt_KeyRsa_GeneratePair2(unsigned int nbits, int use65537e,
   rc=gcry_sexp_new(&keyparm, buffer, 0, 1);
   if (rc) {
     DBG_ERROR(GWEN_LOGDOMAIN,
-	      "Error creating S-expression: %s", gpg_strerror (rc));
+              "Error creating S-expression: %s", gpg_strerror (rc));
     return GWEN_ERROR_GENERIC;
   }
 
@@ -167,7 +166,7 @@ int GWEN_Crypt_KeyRsa_GeneratePair2(unsigned int nbits, int use65537e,
     }
 
     /* create public key */
-    k=GWEN_Crypt_Key_new(GWEN_Crypt_CryptAlgoId_Rsa, nbits/8);
+    k=GWEN_Crypt_Key_new(GWEN_Crypt_CryptAlgoId_Rsa, nbytes);
     GWEN_NEW_OBJECT(GWEN_CRYPT_KEY_RSA, xk);
     GWEN_INHERIT_SETDATA(GWEN_CRYPT_KEY, GWEN_CRYPT_KEY_RSA, k, xk, GWEN_Crypt_KeyRsa_freeData);
     GWEN_Crypt_Key_SetSignFn(k, GWEN_Crypt_KeyRsa_Sign);
@@ -224,7 +223,7 @@ int GWEN_Crypt_KeyRsa_GeneratePair2(unsigned int nbits, int use65537e,
     }
 
     /* create private key */
-    k=GWEN_Crypt_Key_new(GWEN_Crypt_CryptAlgoId_Rsa, nbits/8);
+    k=GWEN_Crypt_Key_new(GWEN_Crypt_CryptAlgoId_Rsa, nbytes);
     GWEN_NEW_OBJECT(GWEN_CRYPT_KEY_RSA, xk);
     GWEN_INHERIT_SETDATA(GWEN_CRYPT_KEY, GWEN_CRYPT_KEY_RSA, k, xk, GWEN_Crypt_KeyRsa_freeData);
     GWEN_Crypt_Key_SetSignFn(k, GWEN_Crypt_KeyRsa_Sign);
@@ -252,24 +251,31 @@ int GWEN_Crypt_KeyRsa_GeneratePair2(unsigned int nbits, int use65537e,
 
 
 
-int GWEN_Crypt_KeyRsa_GeneratePair(unsigned int nbytes, int use65537e,
-				   GWEN_CRYPT_KEY **pPubKey,
-				   GWEN_CRYPT_KEY **pSecretKey) {
-  return GWEN_Crypt_KeyRsa_GeneratePair2(nbytes*8, use65537e, pPubKey, pSecretKey);
+#ifndef NO_DEPRECATED_SYMBOLS
+int GWEN_Crypt_KeyRsa_GeneratePair2(unsigned int nbits, int use65537e,
+                                    GWEN_CRYPT_KEY **pPubKey,
+                                    GWEN_CRYPT_KEY **pSecretKey) {
+  if (nbits%8) {
+    DBG_ERROR(GWEN_LOGDOMAIN,
+              "nbits is required to be a multiple of 8 (%d)", nbits);
+    return GWEN_ERROR_INVALID;
+  }
+  return GWEN_Crypt_KeyRsa_GeneratePair(nbits/8, use65537e, pPubKey, pSecretKey);
 }
+#endif // ifndef NO_DEPRECATED_SYMBOLS
 
 
 
 
-int GWEN_Crypt_KeyRsa_Sign(GWEN_CRYPT_KEY *k,
-			   const uint8_t *pInData,
-			   uint32_t inLen,
-			   uint8_t *pSignatureData,
-			   uint32_t *pSignatureLen) {
+GWENHYWFAR_CB int GWEN_Crypt_KeyRsa_Sign(GWEN_CRYPT_KEY *k,
+    const uint8_t *pInData,
+    uint32_t inLen,
+    uint8_t *pSignatureData,
+    uint32_t *pSignatureLen) {
   GWEN_CRYPT_KEY_RSA *xk;
   gcry_error_t err;
   size_t nscanned;
-  gcry_mpi_t mpi_in;
+  gcry_mpi_t mpi_in=NULL;
   gcry_mpi_t mpi_sigout1;
   gcry_mpi_t mpi_sigout2=NULL;
   size_t nwritten;
@@ -289,7 +295,6 @@ int GWEN_Crypt_KeyRsa_Sign(GWEN_CRYPT_KEY *k,
   }
 
   /* convert input to MPI */
-  mpi_in=gcry_mpi_new(GWEN_Crypt_Key_GetKeySize(k));
   err=gcry_mpi_scan(&mpi_in, GCRYMPI_FMT_USG, pInData, inLen, &nscanned);
   if (err) {
     DBG_INFO(GWEN_LOGDOMAIN, "gcry_mpi_scan(): %s", gcry_strerror(err));
@@ -318,8 +323,8 @@ int GWEN_Crypt_KeyRsa_Sign(GWEN_CRYPT_KEY *k,
 
   /* convert signature MPI */
   err=gcry_mpi_print(GCRYMPI_FMT_USG,
-		     pSignatureData, *pSignatureLen,
-		     &nwritten, mpi_sigout1);
+                     pSignatureData, *pSignatureLen,
+                     &nwritten, mpi_sigout1);
   gcry_mpi_release(mpi_sigout1);
   if (err) {
     DBG_INFO(GWEN_LOGDOMAIN, "gcry_mpi_print(): %s", gcry_strerror(err));
@@ -332,16 +337,16 @@ int GWEN_Crypt_KeyRsa_Sign(GWEN_CRYPT_KEY *k,
 
 
 
-int GWEN_Crypt_KeyRsa_Verify(GWEN_CRYPT_KEY *k,
-			     const uint8_t *pInData,
-			     uint32_t inLen,
-			     const uint8_t *pSignatureData,
-			     uint32_t signatureLen) {
+static GWENHYWFAR_CB int GWEN_Crypt_KeyRsa_Verify(GWEN_CRYPT_KEY *k,
+    const uint8_t *pInData,
+    uint32_t inLen,
+    const uint8_t *pSignatureData,
+    uint32_t signatureLen) {
   GWEN_CRYPT_KEY_RSA *xk;
   gcry_error_t err;
   size_t nscanned;
-  gcry_mpi_t mpi_in;
-  gcry_mpi_t mpi_sigin1;
+  gcry_mpi_t mpi_in=NULL;
+  gcry_mpi_t mpi_sigin1=NULL;
   gcry_mpi_t mpi_sigout;
 
   assert(k);
@@ -360,7 +365,6 @@ int GWEN_Crypt_KeyRsa_Verify(GWEN_CRYPT_KEY *k,
 
 
   /* convert input to MPI */
-  mpi_in=gcry_mpi_new(GWEN_Crypt_Key_GetKeySize(k));
   err=gcry_mpi_scan(&mpi_in, GCRYMPI_FMT_USG, pInData, inLen, &nscanned);
   if (err) {
     DBG_INFO(GWEN_LOGDOMAIN, "gcry_mpi_scan(): %s", gcry_strerror(err));
@@ -369,10 +373,9 @@ int GWEN_Crypt_KeyRsa_Verify(GWEN_CRYPT_KEY *k,
   }
 
   /* convert signature to MPI */
-  mpi_sigin1=gcry_mpi_new(GWEN_Crypt_Key_GetKeySize(k));
   err=gcry_mpi_scan(&mpi_sigin1, GCRYMPI_FMT_USG,
-		    pSignatureData, signatureLen,
-		    &nscanned);
+                    pSignatureData, signatureLen,
+                    &nscanned);
   if (err) {
     DBG_INFO(GWEN_LOGDOMAIN, "gcry_mpi_scan(): %s", gcry_strerror(err));
     gcry_mpi_release(mpi_sigin1);
@@ -412,15 +415,15 @@ int GWEN_Crypt_KeyRsa_Verify(GWEN_CRYPT_KEY *k,
 
 
 
-int GWEN_Crypt_KeyRsa_Encipher(GWEN_CRYPT_KEY *k,
-			       const uint8_t *pInData,
-			       uint32_t inLen,
-			       uint8_t *pOutData,
-			       uint32_t *pOutLen) {
+static GWENHYWFAR_CB int GWEN_Crypt_KeyRsa_Encipher(GWEN_CRYPT_KEY *k,
+    const uint8_t *pInData,
+    uint32_t inLen,
+    uint8_t *pOutData,
+    uint32_t *pOutLen) {
   GWEN_CRYPT_KEY_RSA *xk;
   gcry_error_t err;
   size_t nscanned;
-  gcry_mpi_t mpi_in;
+  gcry_mpi_t mpi_in=NULL;
   gcry_mpi_t mpi_out;
   size_t nwritten;
 
@@ -440,7 +443,6 @@ int GWEN_Crypt_KeyRsa_Encipher(GWEN_CRYPT_KEY *k,
 
 
   /* convert input to MPI */
-  mpi_in=gcry_mpi_new(GWEN_Crypt_Key_GetKeySize(k));
   err=gcry_mpi_scan(&mpi_in, GCRYMPI_FMT_USG, pInData, inLen, &nscanned);
   if (err) {
     DBG_INFO(GWEN_LOGDOMAIN, "gcry_mpi_scan(): %s", gcry_strerror(err));
@@ -457,8 +459,8 @@ int GWEN_Crypt_KeyRsa_Encipher(GWEN_CRYPT_KEY *k,
 
   /* convert result MPI */
   err=gcry_mpi_print(GCRYMPI_FMT_USG,
-		     pOutData, *pOutLen,
-		     &nwritten, mpi_out);
+                     pOutData, *pOutLen,
+                     &nwritten, mpi_out);
   gcry_mpi_release(mpi_out);
   if (err) {
     DBG_INFO(GWEN_LOGDOMAIN, "gcry_mpi_print(): %s", gcry_strerror(err));
@@ -471,15 +473,15 @@ int GWEN_Crypt_KeyRsa_Encipher(GWEN_CRYPT_KEY *k,
 
 
 
-int GWEN_Crypt_KeyRsa_Decipher(GWEN_CRYPT_KEY *k,
-			       const uint8_t *pInData,
-			       uint32_t inLen,
-			       uint8_t *pOutData,
-			       uint32_t *pOutLen) {
+static GWENHYWFAR_CB int GWEN_Crypt_KeyRsa_Decipher(GWEN_CRYPT_KEY *k,
+    const uint8_t *pInData,
+    uint32_t inLen,
+    uint8_t *pOutData,
+    uint32_t *pOutLen) {
   GWEN_CRYPT_KEY_RSA *xk;
   gcry_error_t err;
   size_t nscanned;
-  gcry_mpi_t mpi_in;
+  gcry_mpi_t mpi_in=NULL;
   gcry_mpi_t mpi_out;
   size_t nwritten;
 
@@ -499,7 +501,6 @@ int GWEN_Crypt_KeyRsa_Decipher(GWEN_CRYPT_KEY *k,
 
 
   /* convert input to MPI */
-  mpi_in=gcry_mpi_new(GWEN_Crypt_Key_GetKeySize(k));
   err=gcry_mpi_scan(&mpi_in, GCRYMPI_FMT_USG, pInData, inLen, &nscanned);
   if (err) {
     DBG_INFO(GWEN_LOGDOMAIN, "gcry_mpi_scan(): %s", gcry_strerror(err));
@@ -516,8 +517,8 @@ int GWEN_Crypt_KeyRsa_Decipher(GWEN_CRYPT_KEY *k,
 
   /* convert result MPI */
   err=gcry_mpi_print(GCRYMPI_FMT_USG,
-		     pOutData, *pOutLen,
-		     &nwritten, mpi_out);
+                     pOutData, *pOutLen,
+                     &nwritten, mpi_out);
   gcry_mpi_release(mpi_out);
   if (err) {
     DBG_INFO(GWEN_LOGDOMAIN, "gcry_mpi_print(): %s", gcry_strerror(err));
@@ -530,7 +531,7 @@ int GWEN_Crypt_KeyRsa_Decipher(GWEN_CRYPT_KEY *k,
 
 
 
-int GWEN_Crypt_KeyRsa__ReadMpi(GWEN_DB_NODE *db, const char *dbName, gcry_mpi_t *pMpi) {
+static int GWEN_Crypt_KeyRsa__ReadMpi(GWEN_DB_NODE *db, const char *dbName, gcry_mpi_t *pMpi) {
   gcry_error_t err;
   const void *p;
   unsigned int len;
@@ -547,8 +548,7 @@ int GWEN_Crypt_KeyRsa__ReadMpi(GWEN_DB_NODE *db, const char *dbName, gcry_mpi_t
   err=gcry_mpi_scan(&mpi, GCRYMPI_FMT_USG, p, len, &nscanned);
   if (err) {
     DBG_INFO(GWEN_LOGDOMAIN, "gcry_mpi_scan(): %s", gcry_strerror(err));
-    if (mpi)
-      gcry_mpi_release(mpi);
+    gcry_mpi_release(mpi);
     return GWEN_ERROR_GENERIC;
   }
   if (nscanned<1) {
@@ -565,7 +565,7 @@ int GWEN_Crypt_KeyRsa__ReadMpi(GWEN_DB_NODE *db, const char *dbName, gcry_mpi_t
 
 
 
-int GWEN_Crypt_KeyRsa__WriteMpi(GWEN_DB_NODE *db, const char *dbName, const gcry_mpi_t mpi) {
+static int GWEN_Crypt_KeyRsa__WriteMpi(GWEN_DB_NODE *db, const char *dbName, const gcry_mpi_t mpi) {
   gcry_error_t err;
   unsigned char *buf;
   size_t nbytes;
@@ -577,8 +577,8 @@ int GWEN_Crypt_KeyRsa__WriteMpi(GWEN_DB_NODE *db, const char *dbName, const gcry
     return GWEN_ERROR_GENERIC;
   }
   GWEN_DB_SetBinValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
-		      dbName,
-		      buf, nbytes);
+                      dbName,
+                      buf, nbytes);
   gcry_free(buf);
 
   return 0;
@@ -586,7 +586,7 @@ int GWEN_Crypt_KeyRsa__WriteMpi(GWEN_DB_NODE *db, const char *dbName, const gcry
 
 
 
-int GWEN_Crypt_KeyRsa__MpiToBuffer(const gcry_mpi_t mpi, unsigned char *buf, size_t nbytes) {
+static int GWEN_Crypt_KeyRsa__MpiToBuffer(const gcry_mpi_t mpi, unsigned char *buf, size_t nbytes) {
   gcry_error_t err;
   size_t nwritten=0;
 
@@ -602,7 +602,7 @@ int GWEN_Crypt_KeyRsa__MpiToBuffer(const gcry_mpi_t mpi, unsigned char *buf, siz
 
 
 
-GWENHYWFAR_CB
+static GWENHYWFAR_CB
 void GWEN_Crypt_KeyRsa_freeData(GWEN_UNUSED void *bp, void *p) {
   GWEN_CRYPT_KEY_RSA *xk;
 
@@ -645,7 +645,7 @@ GWEN_CRYPT_KEY *GWEN_Crypt_KeyRsa_fromDb(GWEN_DB_NODE *db) {
   /* extend key */
   GWEN_NEW_OBJECT(GWEN_CRYPT_KEY_RSA, xk);
   GWEN_INHERIT_SETDATA(GWEN_CRYPT_KEY, GWEN_CRYPT_KEY_RSA, k, xk,
-		       GWEN_Crypt_KeyRsa_freeData);
+                       GWEN_Crypt_KeyRsa_freeData);
   GWEN_Crypt_Key_SetSignFn(k, GWEN_Crypt_KeyRsa_Sign);
   GWEN_Crypt_Key_SetVerifyFn(k, GWEN_Crypt_KeyRsa_Verify);
   GWEN_Crypt_Key_SetEncipherFn(k, GWEN_Crypt_KeyRsa_Encipher);
@@ -715,9 +715,9 @@ int GWEN_Crypt_KeyRsa_toDb(const GWEN_CRYPT_KEY *k, GWEN_DB_NODE *db, int pub) {
   assert(dbR);
 
   GWEN_DB_SetIntValue(dbR, GWEN_DB_FLAGS_OVERWRITE_VARS,
-		      "isPublic", pub);
+                      "isPublic", pub);
   GWEN_DB_SetIntValue(dbR, GWEN_DB_FLAGS_OVERWRITE_VARS,
-		      "flags", xk->flags);
+                      "flags", xk->flags);
 
   /* store n */
   rv=GWEN_Crypt_KeyRsa__WriteMpi(dbR, "n", xk->modulus);
@@ -816,10 +816,10 @@ int GWEN_Crypt_KeyRsa_GetSecretExponent(const GWEN_CRYPT_KEY *k, uint8_t *buffer
 
 
 GWEN_CRYPT_KEY *GWEN_Crypt_KeyRsa_fromModExp(unsigned int nbytes,
-					     const uint8_t *pModulus,
-					     uint32_t lModulus,
-					     const uint8_t *pExponent,
-					     uint32_t lExponent) {
+    const uint8_t *pModulus,
+    uint32_t lModulus,
+    const uint8_t *pExponent,
+    uint32_t lExponent) {
   GWEN_DB_NODE *dbKey;
   GWEN_DB_NODE *dbR;
   GWEN_CRYPT_KEY *key;
@@ -835,26 +835,26 @@ GWEN_CRYPT_KEY *GWEN_Crypt_KeyRsa_fromModExp(unsigned int nbytes,
 
   /* basic key stuff */
   GWEN_DB_SetCharValue(dbKey, GWEN_DB_FLAGS_OVERWRITE_VARS,
-		       "cryptAlgoId",
-		       GWEN_Crypt_CryptAlgoId_toString(GWEN_Crypt_CryptAlgoId_Rsa));
+                       "cryptAlgoId",
+                       GWEN_Crypt_CryptAlgoId_toString(GWEN_Crypt_CryptAlgoId_Rsa));
   GWEN_DB_SetIntValue(dbKey, GWEN_DB_FLAGS_OVERWRITE_VARS,
-		      "keySize", nbytes);
+                      "keySize", nbytes);
 
   /* RSA stuff */
   GWEN_DB_SetIntValue(dbR, GWEN_DB_FLAGS_OVERWRITE_VARS,
-		      "isPublic", 1);
+                      "isPublic", 1);
   GWEN_DB_SetBinValue(dbR, GWEN_DB_FLAGS_OVERWRITE_VARS,
-		      "n",
+                      "n",
                       pModulus, lModulus);
   GWEN_DB_SetBinValue(dbR, GWEN_DB_FLAGS_OVERWRITE_VARS,
-		      "e",
+                      "e",
                       pExponent, lExponent);
 
   /* create key from DB */
   key=GWEN_Crypt_KeyRsa_fromDb(dbKey);
   if (key==NULL) {
     DBG_INFO(GWEN_LOGDOMAIN,
-	     "Internal error: Bad RSA key group");
+             "Internal error: Bad RSA key group");
     GWEN_DB_Dump(dbKey, 2);
     GWEN_DB_Group_free(dbKey);
     return NULL;
@@ -867,12 +867,12 @@ GWEN_CRYPT_KEY *GWEN_Crypt_KeyRsa_fromModExp(unsigned int nbytes,
 
 
 GWEN_CRYPT_KEY *GWEN_Crypt_KeyRsa_fromModPrivExp(unsigned int nbytes,
-						 const uint8_t *pModulus,
-						 uint32_t lModulus,
-						 const uint8_t *pExponent,
-						 uint32_t lExponent,
-						 const uint8_t *pPrivExponent,
-						 uint32_t lPrivExponent) {
+    const uint8_t *pModulus,
+    uint32_t lModulus,
+    const uint8_t *pExponent,
+    uint32_t lExponent,
+    const uint8_t *pPrivExponent,
+    uint32_t lPrivExponent) {
   GWEN_DB_NODE *dbKey;
   GWEN_DB_NODE *dbR;
   GWEN_CRYPT_KEY *key;
@@ -890,29 +890,29 @@ GWEN_CRYPT_KEY *GWEN_Crypt_KeyRsa_fromModPrivExp(unsigned int nbytes,
 
   /* basic key stuff */
   GWEN_DB_SetCharValue(dbKey, GWEN_DB_FLAGS_OVERWRITE_VARS,
-		       "cryptAlgoId",
-		       GWEN_Crypt_CryptAlgoId_toString(GWEN_Crypt_CryptAlgoId_Rsa));
+                       "cryptAlgoId",
+                       GWEN_Crypt_CryptAlgoId_toString(GWEN_Crypt_CryptAlgoId_Rsa));
   GWEN_DB_SetIntValue(dbKey, GWEN_DB_FLAGS_OVERWRITE_VARS,
-		      "keySize", nbytes);
+                      "keySize", nbytes);
 
   /* RSA stuff */
   GWEN_DB_SetIntValue(dbR, GWEN_DB_FLAGS_OVERWRITE_VARS,
-		      "isPublic", 0);
+                      "isPublic", 0);
   GWEN_DB_SetBinValue(dbR, GWEN_DB_FLAGS_OVERWRITE_VARS,
-		      "n",
+                      "n",
                       pModulus, lModulus);
   GWEN_DB_SetBinValue(dbR, GWEN_DB_FLAGS_OVERWRITE_VARS,
-		      "e",
+                      "e",
                       pExponent, lExponent);
   GWEN_DB_SetBinValue(dbR, GWEN_DB_FLAGS_OVERWRITE_VARS,
-		      "d",
-		      pPrivExponent, lPrivExponent);
+                      "d",
+                      pPrivExponent, lPrivExponent);
 
   /* create key from DB */
   key=GWEN_Crypt_KeyRsa_fromDb(dbKey);
   if (key==NULL) {
     DBG_INFO(GWEN_LOGDOMAIN,
-	     "Internal error: Bad RSA key group");
+             "Internal error: Bad RSA key group");
     GWEN_DB_Dump(dbKey, 2);
     GWEN_DB_Group_free(dbKey);
     return NULL;
