@@ -55,7 +55,7 @@ static int GWEN_INETADDR__Counter=0;
 #endif
 
 
-uint32_t GWEN_InetAddr_GetCapabilities(){
+uint32_t GWEN_InetAddr_GetCapabilities(void) {
   return
     GWEN_INETADDR_CAPS_AF_TCP |
     GWEN_INETADDR_CAPS_AF_UNIX;
@@ -63,19 +63,19 @@ uint32_t GWEN_InetAddr_GetCapabilities(){
 
 
 
-int GWEN_InetAddr_ModuleInit(){
+int GWEN_InetAddr_ModuleInit(void) {
   return 0;
 }
 
 
 
-int GWEN_InetAddr_ModuleFini(){
+int GWEN_InetAddr_ModuleFini(void) {
   return 0;
 }
 
 
 
-GWEN_INETADDRESS *GWEN_InetAddr_new(GWEN_AddressFamily af){
+GWEN_INETADDRESS *GWEN_InetAddr_new(GWEN_AddressFamily af) {
   GWEN_INETADDRESS *ia;
 
   GWEN_NEW_OBJECT(GWEN_INETADDRESS, ia);
@@ -132,7 +132,7 @@ GWEN_INETADDRESS *GWEN_InetAddr_new(GWEN_AddressFamily af){
 
 
 
-GWEN_INETADDRESS *GWEN_InetAddr_dup(const GWEN_INETADDRESS *oa){
+GWEN_INETADDRESS *GWEN_InetAddr_dup(const GWEN_INETADDRESS *oa) {
   GWEN_INETADDRESS *ia;
 
   GWEN_NEW_OBJECT(GWEN_INETADDRESS, ia);
@@ -149,7 +149,7 @@ GWEN_INETADDRESS *GWEN_InetAddr_dup(const GWEN_INETADDRESS *oa){
 
 
 
-void GWEN_InetAddr_free(GWEN_INETADDRESS *ia){
+void GWEN_InetAddr_free(GWEN_INETADDRESS *ia) {
   if (ia) {
 #ifdef MEMTRACE
     GWEN_INETADDR__Counter--;
@@ -163,7 +163,7 @@ void GWEN_InetAddr_free(GWEN_INETADDRESS *ia){
 
 
 int GWEN_InetAddr_SetAddress(GWEN_INETADDRESS *ia,
-			     const char *addr){
+                             const char *addr) {
   assert(ia);
 
   switch (ia->af) {
@@ -186,7 +186,7 @@ int GWEN_InetAddr_SetAddress(GWEN_INETADDRESS *ia,
       /* ok, address to be set */
       if (!inet_aton(addr,&aptr->sin_addr))
         /* bad address, so maybe it rather is a name */
-	return GWEN_ERROR_BAD_ADDRESS;
+        return GWEN_ERROR_BAD_ADDRESS;
     }
     break;
   }
@@ -207,10 +207,10 @@ int GWEN_InetAddr_SetAddress(GWEN_INETADDRESS *ia,
     if (addr) {
       /* ok, address to be set */
       if ((strlen(addr)+1)>sizeof(aptr->sun_path)) {
-	/* bad address */
-	DBG_INFO(GWEN_LOGDOMAIN, "Path too long (%d>%d)",
-		  (int)(strlen(addr)+1),(int)(sizeof(aptr->sun_path)));
-	return GWEN_ERROR_BAD_ADDRESS;
+        /* bad address */
+        DBG_INFO(GWEN_LOGDOMAIN, "Path too long (%d>%d)",
+                 (int)(strlen(addr)+1),(int)(sizeof(aptr->sun_path)));
+        return GWEN_ERROR_BAD_ADDRESS;
       }
       strcpy(aptr->sun_path, addr);
       ia->size=SUN_LEN(aptr);
@@ -254,7 +254,7 @@ int GWEN_InetAddr_TranslateHError(int herr) {
 
 
 
-int GWEN_InetAddr_SetName(GWEN_INETADDRESS *ia, const char *name){
+int GWEN_InetAddr_SetName(GWEN_INETADDRESS *ia, const char *name) {
   struct hostent *he;
 
   assert(ia);
@@ -270,8 +270,8 @@ int GWEN_InetAddr_SetName(GWEN_INETADDRESS *ia, const char *name){
       return GWEN_InetAddr_TranslateHError(h_errno);
     /* name resolved, store address */
     memcpy(&(aptr->sin_addr),
-	   he->h_addr_list[0],
-	   sizeof(struct in_addr));
+           he->h_addr_list[0],
+           sizeof(struct in_addr));
     break;
   }
 
@@ -293,9 +293,9 @@ int GWEN_InetAddr_SetName(GWEN_INETADDRESS *ia, const char *name){
       /* ok, address to be set */
       if ((strlen(name)+1)>sizeof(aptr->sun_path)) {
         /* bad address */
-	DBG_INFO(GWEN_LOGDOMAIN, "Path too long (%d>%d)",
-		  (int)(strlen(name)+1),(int)(sizeof(aptr->sun_path)));
-	return GWEN_ERROR_BAD_ADDRESS;
+        DBG_INFO(GWEN_LOGDOMAIN, "Path too long (%d>%d)",
+                 (int)(strlen(name)+1),(int)(sizeof(aptr->sun_path)));
+        return GWEN_ERROR_BAD_ADDRESS;
       }
       strcpy(aptr->sun_path,name);
       ia->size=SUN_LEN(aptr);
@@ -312,7 +312,7 @@ int GWEN_InetAddr_SetName(GWEN_INETADDRESS *ia, const char *name){
 
 
 int GWEN_InetAddr_GetAddress(const GWEN_INETADDRESS *ia,
-			     char *buffer, unsigned int bsize){
+                             char *buffer, unsigned int bsize) {
   const char *s;
 
   assert(ia);
@@ -355,7 +355,7 @@ int GWEN_InetAddr_GetAddress(const GWEN_INETADDRESS *ia,
 
 
 int GWEN_InetAddr_GetName(const GWEN_INETADDRESS *ia,
-			  char *buffer, unsigned int bsize){
+                          char *buffer, unsigned int bsize) {
   struct hostent *he;
   struct in_addr lia;
 
@@ -408,7 +408,7 @@ int GWEN_InetAddr_GetName(const GWEN_INETADDRESS *ia,
 
 
 
-int GWEN_InetAddr_GetPort(const GWEN_INETADDRESS *ia){
+int GWEN_InetAddr_GetPort(const GWEN_INETADDRESS *ia) {
   int i;
 
   assert(ia);
@@ -432,7 +432,7 @@ int GWEN_InetAddr_GetPort(const GWEN_INETADDRESS *ia){
 
 
 
-int GWEN_InetAddr_SetPort(GWEN_INETADDRESS *ia, int port){
+int GWEN_InetAddr_SetPort(GWEN_INETADDRESS *ia, int port) {
   assert(ia);
 
   switch (ia->af) {
