@@ -95,6 +95,7 @@ GWEN_SYNCIO *GWEN_SyncIo_File_fromStdHandle(HANDLE hd, const char *hname) {
 
   xio->path=strdup(hname);
   xio->fh=hd;
+  GWEN_SyncIo_SetStatus(sio, GWEN_SyncIo_Status_Connected);
 
   GWEN_SyncIo_SetConnectFn(sio, GWEN_SyncIo_File_Connect);
   GWEN_SyncIo_SetDisconnectFn(sio, GWEN_SyncIo_File_Disconnect);
@@ -129,7 +130,7 @@ const char *GWEN_SyncIo_File_GetPath(const GWEN_SYNCIO *sio) {
 
   assert(sio);
   xio=GWEN_INHERIT_GETDATA(GWEN_SYNCIO, GWEN_SYNCIO_FILE, sio);
-  assert(sio);
+  assert(xio);
 
   return xio->path;
 }
@@ -158,7 +159,7 @@ int GWENHYWFAR_CB GWEN_SyncIo_File_Connect(GWEN_SYNCIO *sio) {
 
   assert(sio);
   xio=GWEN_INHERIT_GETDATA(GWEN_SYNCIO, GWEN_SYNCIO_FILE, sio);
-  assert(sio);
+  assert(xio);
 
   if (xio->fh!=INVALID_HANDLE_VALUE)
     /* already open */
@@ -200,21 +201,22 @@ int GWENHYWFAR_CB GWEN_SyncIo_File_Connect(GWEN_SYNCIO *sio) {
   }
 
   fh=CreateFile(xio->path,
-		dwDesiredAccess,                    /* dwDesiredAccess */
-		FILE_SHARE_READ | FILE_SHARE_WRITE, /* dwShareMode */
-		NULL,                               /* pSecurityAttributes */
-		dwCreationDistribution,             /* dwCreationDistribution */
-		dwFlagsAndAttrs,                    /* dwFlagsAndAttrs */
+                dwDesiredAccess,                    /* dwDesiredAccess */
+                FILE_SHARE_READ | FILE_SHARE_WRITE, /* dwShareMode */
+                NULL,                               /* pSecurityAttributes */
+                dwCreationDistribution,             /* dwCreationDistribution */
+                dwFlagsAndAttrs,                    /* dwFlagsAndAttrs */
                 NULL);                              /* hTemplateFile */
   if (fh==INVALID_HANDLE_VALUE) {
     DBG_ERROR(GWEN_LOGDOMAIN,
-	      "Error opening file[%s]: %d",
+              "Error opening file[%s]: %d",
               xio->path,
-	      (int)GetLastError());
+              (int)GetLastError());
     return GWEN_ERROR_IO;
   }
 
   xio->fh=fh;
+  GWEN_SyncIo_SetStatus(sio, GWEN_SyncIo_Status_Connected);
   return 0;
 }
 
@@ -225,17 +227,17 @@ int GWENHYWFAR_CB GWEN_SyncIo_File_Disconnect(GWEN_SYNCIO *sio) {
 
   assert(sio);
   xio=GWEN_INHERIT_GETDATA(GWEN_SYNCIO, GWEN_SYNCIO_FILE, sio);
-  assert(sio);
+  assert(xio);
 
   if (xio->fh!=INVALID_HANDLE_VALUE) {
     if (!(GWEN_SyncIo_GetFlags(sio) & GWEN_SYNCIO_FLAGS_DONTCLOSE)) {
       if (!CloseHandle(xio->fh)) {
-	DBG_ERROR(GWEN_LOGDOMAIN,
-		  "Error closing file[%s]: %d",
-		  xio->path,
-		  (int)GetLastError());
-	xio->fh=INVALID_HANDLE_VALUE;
-	return GWEN_ERROR_IO;
+        DBG_ERROR(GWEN_LOGDOMAIN,
+                  "Error closing file[%s]: %d",
+                  xio->path,
+                  (int)GetLastError());
+        xio->fh=INVALID_HANDLE_VALUE;
+        return GWEN_ERROR_IO;
       }
     }
     xio->fh=INVALID_HANDLE_VALUE;
@@ -247,14 +249,14 @@ int GWENHYWFAR_CB GWEN_SyncIo_File_Disconnect(GWEN_SYNCIO *sio) {
 
 
 int GWENHYWFAR_CB GWEN_SyncIo_File_Read(GWEN_SYNCIO *sio,
-					uint8_t *buffer,
-					uint32_t size) {
+                                        uint8_t *buffer,
+                                        uint32_t size) {
   GWEN_SYNCIO_FILE *xio;
   DWORD bytesRead=0;
 
   assert(sio);
   xio=GWEN_INHERIT_GETDATA(GWEN_SYNCIO, GWEN_SYNCIO_FILE, sio);
-  assert(sio);
+  assert(xio);
 
   if (xio->fh==INVALID_HANDLE_VALUE) {
     DBG_ERROR(GWEN_LOGDOMAIN, "File is not open");
@@ -264,8 +266,8 @@ int GWENHYWFAR_CB GWEN_SyncIo_File_Read(GWEN_SYNCIO *sio,
 
   if (!ReadFile(xio->fh, buffer, size, &bytesRead, NULL)) {
     DBG_ERROR(GWEN_LOGDOMAIN, "Error on ReadFile(%s): %d",
-	      xio->path,
-	      (int)GetLastError());
+              xio->path,
+              (int)GetLastError());
     return GWEN_ERROR_IO;
   }
 
@@ -275,14 +277,14 @@ int GWENHYWFAR_CB GWEN_SyncIo_File_Read(GWEN_SYNCIO *sio,
 
 
 int GWENHYWFAR_CB GWEN_SyncIo_File_Write(GWEN_SYNCIO *sio,
-					 const uint8_t *buffer,
-					 uint32_t size) {
+    const uint8_t *buffer,
+    uint32_t size) {
   GWEN_SYNCIO_FILE *xio;
   DWORD bytesWritten=0;
 
   assert(sio);
   xio=GWEN_INHERIT_GETDATA(GWEN_SYNCIO, GWEN_SYNCIO_FILE, sio);
-  assert(sio);
+  assert(xio);
 
   if (xio->fh==INVALID_HANDLE_VALUE) {
     DBG_ERROR(GWEN_LOGDOMAIN, "File is not open");
@@ -292,8 +294,8 @@ int GWENHYWFAR_CB GWEN_SyncIo_File_Write(GWEN_SYNCIO *sio,
 
   if (!WriteFile(xio->fh, buffer, size, &bytesWritten, NULL)) {
     DBG_ERROR(GWEN_LOGDOMAIN, "Error on WriteFile(%s): %d",
-	      xio->path,
-	      (int)GetLastError());
+              xio->path,
+              (int)GetLastError());
     return GWEN_ERROR_IO;
   }
 
@@ -309,7 +311,7 @@ int64_t GWEN_SyncIo_File_Seek(GWEN_SYNCIO *sio, int64_t pos, GWEN_SYNCIO_FILE_WH
 
   assert(sio);
   xio=GWEN_INHERIT_GETDATA(GWEN_SYNCIO, GWEN_SYNCIO_FILE, sio);
-  assert(sio);
+  assert(xio);
 
   if (xio->fh==INVALID_HANDLE_VALUE) {
     DBG_ERROR(GWEN_LOGDOMAIN, "File is not open");
@@ -317,9 +319,15 @@ int64_t GWEN_SyncIo_File_Seek(GWEN_SYNCIO *sio, int64_t pos, GWEN_SYNCIO_FILE_WH
   }
 
   switch(whence) {
-  case GWEN_SyncIo_File_Whence_Set:     w=FILE_BEGIN; break;
-  case GWEN_SyncIo_File_Whence_Current: w=FILE_CURRENT; break;
-  case GWEN_SyncIo_File_Whence_End:     w=FILE_END; break;
+  case GWEN_SyncIo_File_Whence_Set:
+    w=FILE_BEGIN;
+    break;
+  case GWEN_SyncIo_File_Whence_Current:
+    w=FILE_CURRENT;
+    break;
+  case GWEN_SyncIo_File_Whence_End:
+    w=FILE_END;
+    break;
   default:
     DBG_ERROR(GWEN_LOGDOMAIN, "Invalid seek mode (%d)", whence);
     return GWEN_ERROR_INVALID;
@@ -327,19 +335,19 @@ int64_t GWEN_SyncIo_File_Seek(GWEN_SYNCIO *sio, int64_t pos, GWEN_SYNCIO_FILE_WH
 
   li.QuadPart = pos;
   li.LowPart=SetFilePointer(xio->fh,
-			    li.LowPart,
-			    &li.HighPart,
-			    w);
+                            li.LowPart,
+                            &li.HighPart,
+                            w);
   if (li.LowPart==INVALID_SET_FILE_POINTER) {
     DWORD rv;
 
     rv=GetLastError();
     if (rv!=NO_ERROR) {
       DBG_ERROR(GWEN_LOGDOMAIN,
-		"Error seeking in file[%s] at %llu: %d",
-		xio->path,
-		(unsigned long long) pos,
-		(int)rv);
+                "Error seeking in file[%s] at %llu: %d",
+                xio->path,
+                (unsigned long long) pos,
+                (int)rv);
       return GWEN_ERROR_IO;
     }
   }
