@@ -69,7 +69,7 @@ GWEN_LIST_FUNCTIONS(GWEN_XMLNODE_NAMESPACE, GWEN_XMLNode_NameSpace)
 
 
 
-GWEN_XMLPROPERTY *GWEN_XMLProperty_new(const char *name, const char *value){
+GWEN_XMLPROPERTY *GWEN_XMLProperty_new(const char *name, const char *value) {
   GWEN_XMLPROPERTY *p;
 
   GWEN_NEW_OBJECT(GWEN_XMLPROPERTY, p);
@@ -82,7 +82,7 @@ GWEN_XMLPROPERTY *GWEN_XMLProperty_new(const char *name, const char *value){
 
 
 
-void GWEN_XMLProperty_free(GWEN_XMLPROPERTY *p){
+void GWEN_XMLProperty_free(GWEN_XMLPROPERTY *p) {
   if (p) {
     GWEN_Memory_dealloc(p->name);
     GWEN_Memory_dealloc(p->value);
@@ -93,7 +93,7 @@ void GWEN_XMLProperty_free(GWEN_XMLPROPERTY *p){
 
 
 
-GWEN_XMLPROPERTY *GWEN_XMLProperty_dup(const GWEN_XMLPROPERTY *p){
+GWEN_XMLPROPERTY *GWEN_XMLProperty_dup(const GWEN_XMLPROPERTY *p) {
   GWEN_XMLPROPERTY *pp;
 
   pp=GWEN_XMLProperty_new(p->name, p->value);
@@ -105,18 +105,18 @@ GWEN_XMLPROPERTY *GWEN_XMLProperty_dup(const GWEN_XMLPROPERTY *p){
 
 
 
-void GWEN_XMLProperty_add(GWEN_XMLPROPERTY *p, GWEN_XMLPROPERTY **head){
+void GWEN_XMLProperty_add(GWEN_XMLPROPERTY *p, GWEN_XMLPROPERTY **head) {
   GWEN_LIST_ADD(GWEN_XMLPROPERTY, p, head);
 }
 
 
 
-void GWEN_XMLProperty_insert(GWEN_XMLPROPERTY *p, GWEN_XMLPROPERTY **head){
+void GWEN_XMLProperty_insert(GWEN_XMLPROPERTY *p, GWEN_XMLPROPERTY **head) {
   GWEN_LIST_INSERT(GWEN_XMLPROPERTY, p, head);
 }
 
 
-void GWEN_XMLProperty_del(GWEN_XMLPROPERTY *p, GWEN_XMLPROPERTY **head){
+void GWEN_XMLProperty_del(GWEN_XMLPROPERTY *p, GWEN_XMLPROPERTY **head) {
   GWEN_LIST_DEL(GWEN_XMLPROPERTY, p, head);
 }
 
@@ -134,7 +134,7 @@ void GWEN_XMLProperty_freeAll(GWEN_XMLPROPERTY *p) {
 
 
 
-GWEN_XMLNODE *GWEN_XMLNode_new(GWEN_XMLNODE_TYPE t, const char *data){
+GWEN_XMLNODE *GWEN_XMLNode_new(GWEN_XMLNODE_TYPE t, const char *data) {
   GWEN_XMLNODE *n;
 
   GWEN_NEW_OBJECT(GWEN_XMLNODE, n);
@@ -149,7 +149,7 @@ GWEN_XMLNODE *GWEN_XMLNode_new(GWEN_XMLNODE_TYPE t, const char *data){
 }
 
 
-void GWEN_XMLNode_free(GWEN_XMLNODE *n){
+void GWEN_XMLNode_free(GWEN_XMLNODE *n) {
   if (n) {
     GWEN_LIST_FINI(GWEN_XMLNODE, n);
     GWEN_XMLProperty_freeAll(n->properties);
@@ -163,7 +163,7 @@ void GWEN_XMLNode_free(GWEN_XMLNODE *n){
 }
 
 
-void GWEN_XMLNode_freeAll(GWEN_XMLNODE *n){
+void GWEN_XMLNode_freeAll(GWEN_XMLNODE *n) {
   while(n) {
     GWEN_XMLNODE *next;
 
@@ -174,7 +174,7 @@ void GWEN_XMLNode_freeAll(GWEN_XMLNODE *n){
 }
 
 
-GWEN_XMLNODE *GWEN_XMLNode_dup(const GWEN_XMLNODE *n){
+GWEN_XMLNODE *GWEN_XMLNode_dup(const GWEN_XMLNODE *n) {
   GWEN_XMLNODE *nn, *cn, *ncn;
   const GWEN_XMLPROPERTY *p;
   const GWEN_XMLNODE_NAMESPACE *nns;
@@ -226,7 +226,7 @@ GWEN_XMLNODE *GWEN_XMLNode_dup(const GWEN_XMLNODE *n){
 
 
 const char *GWEN_XMLNode_GetProperty(const GWEN_XMLNODE *n, const char *name,
-                                     const char *defaultValue){
+                                     const char *defaultValue) {
   GWEN_XMLPROPERTY *p;
 
   assert(n);
@@ -247,9 +247,36 @@ const char *GWEN_XMLNode_GetProperty(const GWEN_XMLNODE *n, const char *name,
 }
 
 
+
+int GWEN_XMLNode_GetIntProperty(const GWEN_XMLNODE *n, const char *name,
+                                int defaultValue) {
+  GWEN_XMLPROPERTY *p;
+
+  assert(n);
+  assert(name);
+  p=n->properties;
+  while(p) {
+    assert(p->name);
+    if (strcasecmp(p->name, name)==0)
+      break;
+    p=p->next;
+  } /* while */
+
+  if (p) {
+    if (p->value) {
+      int i;
+
+      if (1==sscanf(p->value, "%i", &i))
+        return i;
+    }
+  }
+  return defaultValue;
+}
+
+
 void GWEN_XMLNode__SetProperty(GWEN_XMLNODE *n,
                                const char *name, const char *value,
-                               int doInsert){
+                               int doInsert) {
   GWEN_XMLPROPERTY *p;
 
   p=n->properties;
@@ -279,20 +306,31 @@ void GWEN_XMLNode__SetProperty(GWEN_XMLNODE *n,
 
 
 void GWEN_XMLNode_SetProperty(GWEN_XMLNODE *n,
-                              const char *name, const char *value){
+                              const char *name, const char *value) {
   GWEN_XMLNode__SetProperty(n, name, value, 0);
 }
 
 
 
-void GWEN_XMLNode_IncUsage(GWEN_XMLNODE *n){
+void GWEN_XMLNode_SetIntProperty(GWEN_XMLNODE *n,
+                                 const char *name, int value) {
+  char numbuf[256];
+
+  snprintf(numbuf, sizeof(numbuf)-1, "%i", value);
+  numbuf[sizeof(numbuf)-1]=0;
+  GWEN_XMLNode__SetProperty(n, name, numbuf, 0);
+}
+
+
+
+void GWEN_XMLNode_IncUsage(GWEN_XMLNODE *n) {
   assert(n);
   n->usage++;
 }
 
 
 
-void GWEN_XMLNode_DecUsage(GWEN_XMLNODE *n){
+void GWEN_XMLNode_DecUsage(GWEN_XMLNODE *n) {
   assert(n);
   if (n->usage==0) {
     DBG_WARN(GWEN_LOGDOMAIN, "Node usage already is zero");
@@ -303,20 +341,20 @@ void GWEN_XMLNode_DecUsage(GWEN_XMLNODE *n){
 
 
 
-uint32_t GWEN_XMLNode_GetUsage(const GWEN_XMLNODE *n){
+uint32_t GWEN_XMLNode_GetUsage(const GWEN_XMLNODE *n) {
   assert(n);
   return n->usage;
 }
 
 
 
-const char *GWEN_XMLNode_GetData(const GWEN_XMLNODE *n){
+const char *GWEN_XMLNode_GetData(const GWEN_XMLNODE *n) {
   assert(n);
   return n->data;
 }
 
 
-void GWEN_XMLNode_SetData(GWEN_XMLNODE *n, const char *data){
+void GWEN_XMLNode_SetData(GWEN_XMLNODE *n, const char *data) {
   assert(n);
   GWEN_Memory_dealloc(n->data);
   if (data)
@@ -345,19 +383,19 @@ void GWEN_XMLNode_SetNamespace(GWEN_XMLNODE *n, const char *s) {
 
 
 
-GWEN_XMLNODE *GWEN_XMLNode_GetChild(const GWEN_XMLNODE *n){
+GWEN_XMLNODE *GWEN_XMLNode_GetChild(const GWEN_XMLNODE *n) {
   assert(n);
   return GWEN_XMLNode_List_First(n->children);
 }
 
 
-GWEN_XMLNODE *GWEN_XMLNode_GetParent(const GWEN_XMLNODE *n){
+GWEN_XMLNODE *GWEN_XMLNode_GetParent(const GWEN_XMLNODE *n) {
   assert(n);
   return n->parent;
 }
 
 
-void GWEN_XMLNode_AddChild(GWEN_XMLNODE *n, GWEN_XMLNODE *child){
+void GWEN_XMLNode_AddChild(GWEN_XMLNODE *n, GWEN_XMLNODE *child) {
   assert(n);
   GWEN_XMLNode_List_Add(child, n->children);
   child->parent=n;
@@ -366,7 +404,7 @@ void GWEN_XMLNode_AddChild(GWEN_XMLNODE *n, GWEN_XMLNODE *child){
 
 
 void GWEN_XMLNode_AddChildrenOnly(GWEN_XMLNODE *n, GWEN_XMLNODE *nn,
-                                  int copythem){
+                                  int copythem) {
   GWEN_XMLNODE *ch;
 
   assert(n);
@@ -390,7 +428,7 @@ void GWEN_XMLNode_AddChildrenOnly(GWEN_XMLNODE *n, GWEN_XMLNODE *nn,
 
 
 
-GWEN_XMLNODE_TYPE GWEN_XMLNode_GetType(const GWEN_XMLNODE *n){
+GWEN_XMLNODE_TYPE GWEN_XMLNode_GetType(const GWEN_XMLNODE *n) {
   assert(n);
   return n->type;
 }
@@ -484,7 +522,7 @@ GWEN_XMLNODE *GWEN_XMLNode_FindNode(const GWEN_XMLNODE *node,
     if (n->type==t)
       if (n->data)
         if (strcasecmp(n->data, data)==0)
-	  break;
+          break;
     n=GWEN_XMLNode_Next(n);
   } /* while */
 
@@ -498,7 +536,7 @@ GWEN_XMLNODE *GWEN_XMLNode_FindNode(const GWEN_XMLNODE *node,
 
 
 
-void GWEN_XMLNode_UnlinkChild(GWEN_XMLNODE *n, GWEN_XMLNODE *child){
+void GWEN_XMLNode_UnlinkChild(GWEN_XMLNODE *n, GWEN_XMLNODE *child) {
   assert(n);
   assert(child);
   GWEN_XMLNode_List_Del(child);
@@ -507,7 +545,7 @@ void GWEN_XMLNode_UnlinkChild(GWEN_XMLNODE *n, GWEN_XMLNODE *child){
 
 
 
-void GWEN_XMLNode_RemoveChildren(GWEN_XMLNODE *n){
+void GWEN_XMLNode_RemoveChildren(GWEN_XMLNODE *n) {
   assert(n);
   GWEN_XMLNode_List_Clear(n->children);
 }
@@ -516,7 +554,7 @@ void GWEN_XMLNode_RemoveChildren(GWEN_XMLNODE *n){
 
 void GWEN_XMLNode_CopyProperties(GWEN_XMLNODE *tn,
                                  const GWEN_XMLNODE *sn,
-                                 int overwrite){
+                                 int overwrite) {
   const GWEN_XMLPROPERTY *sp;
   GWEN_XMLPROPERTY *tp;
 
@@ -534,15 +572,15 @@ void GWEN_XMLNode_CopyProperties(GWEN_XMLNODE *tn,
 
       assert(tp->name);
       if (strcasecmp(tp->name, sp->name)==0) {
-	/* property already exists */
-	if (overwrite) {
+        /* property already exists */
+        if (overwrite) {
           /* overwrite old property */
-	  GWEN_Memory_dealloc(tp->value);
-	  tp->value=0;
-	  if (sp->value)
-	    tp->value=GWEN_Memory_strdup(sp->value);
-	}
-	break;
+          GWEN_Memory_dealloc(tp->value);
+          tp->value=0;
+          if (sp->value)
+            tp->value=GWEN_Memory_strdup(sp->value);
+        }
+        break;
       }
       tp=tp->next;
     } /* while */
@@ -560,7 +598,7 @@ void GWEN_XMLNode_CopyProperties(GWEN_XMLNODE *tn,
 
 
 GWEN_XMLNODE *GWEN_XMLNode_GetFirstOfType(const GWEN_XMLNODE *n,
-                                          GWEN_XMLNODE_TYPE t){
+    GWEN_XMLNODE_TYPE t) {
   GWEN_XMLNODE *nn;
 
   assert(n);
@@ -576,7 +614,7 @@ GWEN_XMLNODE *GWEN_XMLNode_GetFirstOfType(const GWEN_XMLNODE *n,
 
 
 GWEN_XMLNODE *GWEN_XMLNode_GetNextOfType(const GWEN_XMLNODE *n,
-                                         GWEN_XMLNODE_TYPE t){
+    GWEN_XMLNODE_TYPE t) {
   assert(n);
   while(n) {
     if (n->type==t)
@@ -588,13 +626,13 @@ GWEN_XMLNODE *GWEN_XMLNode_GetNextOfType(const GWEN_XMLNODE *n,
 
 
 
-GWEN_XMLNODE *GWEN_XMLNode_GetFirstTag(const GWEN_XMLNODE *n){
+GWEN_XMLNODE *GWEN_XMLNode_GetFirstTag(const GWEN_XMLNODE *n) {
   return GWEN_XMLNode_GetFirstOfType(n, GWEN_XMLNodeTypeTag);
 }
 
 
 
-GWEN_XMLNODE *GWEN_XMLNode_GetNextTag(const GWEN_XMLNODE *n){
+GWEN_XMLNODE *GWEN_XMLNode_GetNextTag(const GWEN_XMLNODE *n) {
   GWEN_XMLNODE *next;
 
   next=GWEN_XMLNode_Next(n);
@@ -605,13 +643,13 @@ GWEN_XMLNODE *GWEN_XMLNode_GetNextTag(const GWEN_XMLNODE *n){
 
 
 
-GWEN_XMLNODE *GWEN_XMLNode_GetFirstData(const GWEN_XMLNODE *n){
+GWEN_XMLNODE *GWEN_XMLNode_GetFirstData(const GWEN_XMLNODE *n) {
   return GWEN_XMLNode_GetFirstOfType(n, GWEN_XMLNodeTypeData);
 }
 
 
 
-GWEN_XMLNODE *GWEN_XMLNode_GetNextData(const GWEN_XMLNODE *n){
+GWEN_XMLNODE *GWEN_XMLNode_GetNextData(const GWEN_XMLNODE *n) {
   GWEN_XMLNODE *next;
 
   next=GWEN_XMLNode_Next(n);
@@ -625,7 +663,7 @@ GWEN_XMLNODE *GWEN_XMLNode_GetNextData(const GWEN_XMLNODE *n){
 GWEN_XMLNODE *GWEN_XMLNode_FindTag(const GWEN_XMLNODE *n,
                                    const char *tname,
                                    const char *pname,
-                                   const char *pvalue){
+                                   const char *pvalue) {
   while(n) {
     if (-1!=GWEN_Text_ComparePattern(n->data, tname, 0)) {
       if (pname) {
@@ -657,7 +695,7 @@ GWEN_XMLNODE *GWEN_XMLNode_FindTag(const GWEN_XMLNODE *n,
 GWEN_XMLNODE *GWEN_XMLNode_FindFirstTag(const GWEN_XMLNODE *n,
                                         const char *tname,
                                         const char *pname,
-                                        const char *pvalue){
+                                        const char *pvalue) {
   GWEN_XMLNODE *nn;
 
   nn=GWEN_XMLNode_GetFirstTag(n);
@@ -674,7 +712,7 @@ GWEN_XMLNODE *GWEN_XMLNode_FindFirstTag(const GWEN_XMLNODE *n,
 GWEN_XMLNODE *GWEN_XMLNode_FindNextTag(const GWEN_XMLNODE *n,
                                        const char *tname,
                                        const char *pname,
-                                       const char *pvalue){
+                                       const char *pvalue) {
   GWEN_XMLNODE *nn;
 
   nn=GWEN_XMLNode_GetNextTag(n);
@@ -693,26 +731,37 @@ const char *GWEN_XMLNode_GetCharValue(const GWEN_XMLNODE *n,
                                       const char *defValue) {
   GWEN_XMLNODE *nn;
 
-  nn=GWEN_XMLNode_FindFirstTag(n, name, 0, 0);
-  while(nn) {
+  if (name && *name) {
+    nn=GWEN_XMLNode_FindFirstTag(n, name, 0, 0);
+
+    while(nn) {
+      GWEN_XMLNODE *dn;
+
+      dn=GWEN_XMLNode_GetFirstData(nn);
+      if (dn) {
+	if (dn->data)
+	  return dn->data;
+      }
+      nn=GWEN_XMLNode_FindNextTag(nn, name, 0, 0);
+    }
+  }
+  else {
     GWEN_XMLNODE *dn;
 
-    dn=GWEN_XMLNode_GetFirstData(nn);
+    dn=GWEN_XMLNode_GetFirstData(n);
     if (dn) {
       if (dn->data)
-        return dn->data;
+	return dn->data;
     }
-    nn=GWEN_XMLNode_FindNextTag(nn, name, 0, 0);
   }
-
   return defValue;
 }
 
 
 
 const char *GWEN_XMLNode_GetLocalizedCharValue(const GWEN_XMLNODE *n,
-                                               const char *name,
-                                               const char *defValue) {
+					       const char *name,
+					       const char *defValue) {
   GWEN_XMLNODE *nn=0;
   GWEN_STRINGLIST *langl;
 
@@ -729,14 +778,14 @@ const char *GWEN_XMLNode_GetLocalizedCharValue(const GWEN_XMLNODE *n,
       assert(l);
       nn=GWEN_XMLNode_FindFirstTag(n, name, "lang", l);
       while(nn) {
-	GWEN_XMLNODE *dn;
+        GWEN_XMLNODE *dn;
 
-	dn=GWEN_XMLNode_GetFirstData(nn);
-	if (dn) {
-	  if (dn->data && *(dn->data))
-	    return dn->data;
-	}
-	nn=GWEN_XMLNode_FindNextTag(nn, name, "lang", l);
+        dn=GWEN_XMLNode_GetFirstData(nn);
+        if (dn) {
+          if (dn->data && *(dn->data))
+            return dn->data;
+        }
+        nn=GWEN_XMLNode_FindNextTag(nn, name, "lang", l);
       } /* while nn */
       se=GWEN_StringListEntry_Next(se);
     } /* while */
@@ -762,17 +811,25 @@ const char *GWEN_XMLNode_GetLocalizedCharValue(const GWEN_XMLNODE *n,
 
 void GWEN_XMLNode_SetCharValue(GWEN_XMLNODE *n,
                                const char *name,
-                               const char *value){
-  GWEN_XMLNODE *nn;
+                               const char *value) {
+  if (name && *name) {
+    GWEN_XMLNODE *nn;
 
-  nn=GWEN_XMLNode_new(GWEN_XMLNodeTypeTag, name);
-  if (value) {
-    GWEN_XMLNODE *nnn;
+    nn=GWEN_XMLNode_new(GWEN_XMLNodeTypeTag, name);
+    if (value) {
+      GWEN_XMLNODE *nnn;
 
-    nnn=GWEN_XMLNode_new(GWEN_XMLNodeTypeData, value);
-    GWEN_XMLNode_AddChild(nn, nnn);
+      nnn=GWEN_XMLNode_new(GWEN_XMLNodeTypeData, value);
+      GWEN_XMLNode_AddChild(nn, nnn);
+    }
+    GWEN_XMLNode_AddChild(n, nn);
+  }
+  else {
+    GWEN_XMLNODE *nn;
+
+    nn=GWEN_XMLNode_new(GWEN_XMLNodeTypeData, value);
+    GWEN_XMLNode_AddChild(n, nn);
   }
-  GWEN_XMLNode_AddChild(n, nn);
 }
 
 
@@ -795,7 +852,7 @@ int GWEN_XMLNode_GetIntValue(const GWEN_XMLNODE *n,
 
 void GWEN_XMLNode_SetIntValue(GWEN_XMLNODE *n,
                               const char *name,
-                              int value){
+                              int value) {
   char numbuf[32];
 
   snprintf(numbuf, sizeof(numbuf)-1, "%d", value);
@@ -805,7 +862,95 @@ void GWEN_XMLNode_SetIntValue(GWEN_XMLNODE *n,
 
 
 
-GWEN_XMLPROPERTY *GWEN_XMLNode_GetFirstProperty(const GWEN_XMLNODE *n){
+int GWEN_XMLNode_SetCharValueByPath(GWEN_XMLNODE *n, uint32_t flags,
+                                    const char *name,
+                                    const char *value) {
+  GWEN_XMLNODE *nn;
+
+  nn=GWEN_XMLNode_GetNodeByXPath(n, name, 0);
+  if (nn) {
+    GWEN_XMLNODE *nnn;
+
+    /* clear current entries */
+    if (flags & GWEN_XML_PATH_FLAGS_OVERWRITE_VALUES)
+      GWEN_XMLNode_List_Clear(nn->children);
+
+    /* create value node */
+    nnn=GWEN_XMLNode_new(GWEN_XMLNodeTypeData, value);
+    GWEN_XMLNode_AddChild(nn, nnn);
+
+    return 0;
+  }
+  else {
+    DBG_ERROR(GWEN_LOGDOMAIN, "Unable to create node [%s]", name);
+    return GWEN_ERROR_INVALID;
+  }
+}
+
+
+
+const char *GWEN_XMLNode_GetCharValueByPath(GWEN_XMLNODE *n,
+    const char *name,
+    const char *defValue) {
+  GWEN_XMLNODE *nn;
+
+  nn=GWEN_XMLNode_GetNodeByXPath(n, name, 0);
+  if (nn) {
+    GWEN_XMLNODE *dn;
+
+    dn=GWEN_XMLNode_GetFirstData(nn);
+    if (dn) {
+      if (dn->data)
+        return dn->data;
+    }
+  }
+
+  return defValue;
+}
+
+
+
+int GWEN_XMLNode_SetIntValueByPath(GWEN_XMLNODE *n, uint32_t flags,
+                                   const char *name,
+                                   int value) {
+  char numbuf[32];
+  int rv;
+
+  /* create int value */
+  snprintf(numbuf, sizeof(numbuf)-1, "%d", value);
+  numbuf[sizeof(numbuf)-1]=0;
+
+  rv=GWEN_XMLNode_SetCharValueByPath(n, flags, name, numbuf);
+  if (rv<0) {
+    DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+    return rv;
+  }
+
+  return rv;
+}
+
+
+
+int GWEN_XMLNode_GetIntValueByPath(GWEN_XMLNODE *n,
+                                   const char *name,
+                                   int defValue) {
+  const char *p;
+  int res;
+
+  p=GWEN_XMLNode_GetCharValueByPath(n, name, NULL);
+  if (!p)
+    return defValue;
+  if (1!=sscanf(p, "%i", &res))
+    return defValue;
+  return res;
+}
+
+
+
+
+
+
+GWEN_XMLPROPERTY *GWEN_XMLNode_GetFirstProperty(const GWEN_XMLNODE *n) {
   assert(n);
   return n->properties;
 }
@@ -813,7 +958,7 @@ GWEN_XMLPROPERTY *GWEN_XMLNode_GetFirstProperty(const GWEN_XMLNODE *n){
 
 
 GWEN_XMLPROPERTY *GWEN_XMLNode_GetNextProperty(const GWEN_XMLNODE *n,
-                                               const GWEN_XMLPROPERTY *pr){
+    const GWEN_XMLPROPERTY *pr) {
   assert(n);
   assert(pr);
   return pr->next;
@@ -821,14 +966,14 @@ GWEN_XMLPROPERTY *GWEN_XMLNode_GetNextProperty(const GWEN_XMLNODE *n,
 
 
 
-const char *GWEN_XMLProperty_GetName(const GWEN_XMLPROPERTY *pr){
+const char *GWEN_XMLProperty_GetName(const GWEN_XMLPROPERTY *pr) {
   assert(pr);
   return pr->name;
 }
 
 
 
-const char *GWEN_XMLProperty_GetValue(const GWEN_XMLPROPERTY *pr){
+const char *GWEN_XMLProperty_GetValue(const GWEN_XMLPROPERTY *pr) {
   assert(pr);
   return pr->value;
 }
@@ -988,16 +1133,16 @@ void* GWEN_XMLNode_HandlePath(const char *entry,
 
   /* check whether we are allowed to simply create the node */
   if (
-      ((flags & GWEN_PATH_FLAGS_LAST) &&
-       (((flags & GWEN_PATH_FLAGS_VARIABLE) &&
-         (flags & GWEN_PATH_FLAGS_CREATE_VAR)) ||
-        (!(flags & GWEN_PATH_FLAGS_VARIABLE) &&
-         (flags & GWEN_PATH_FLAGS_CREATE_GROUP)))
-      ) ||
-      (
-       !(flags & GWEN_PATH_FLAGS_LAST) &&
-       (flags & GWEN_PATH_FLAGS_PATHCREATE))
-     ) {
+    ((flags & GWEN_PATH_FLAGS_LAST) &&
+     (((flags & GWEN_PATH_FLAGS_VARIABLE) &&
+       (flags & GWEN_PATH_FLAGS_CREATE_VAR)) ||
+      (!(flags & GWEN_PATH_FLAGS_VARIABLE) &&
+       (flags & GWEN_PATH_FLAGS_CREATE_GROUP)))
+    ) ||
+    (
+      !(flags & GWEN_PATH_FLAGS_LAST) &&
+      (flags & GWEN_PATH_FLAGS_PATHCREATE))
+  ) {
     /* simply create the new variable/group */
     if (flags & GWEN_PATH_FLAGS_VARIABLE) {
       /* not allowed for now */
@@ -1027,10 +1172,10 @@ void* GWEN_XMLNode_HandlePath(const char *entry,
   if (!nn) {
     /* node not found, check, if we are allowed to create it */
     if (
-        (!(flags & GWEN_PATH_FLAGS_LAST) &&
-         (flags & GWEN_PATH_FLAGS_PATHMUSTEXIST)) ||
-        (flags & GWEN_PATH_FLAGS_NAMEMUSTEXIST)
-       ) {
+      (!(flags & GWEN_PATH_FLAGS_LAST) &&
+       (flags & GWEN_PATH_FLAGS_PATHMUSTEXIST)) ||
+      (flags & GWEN_PATH_FLAGS_NAMEMUSTEXIST)
+    ) {
       DBG_VERBOUS(GWEN_LOGDOMAIN,
                   "Tag \"%s\" does not exist", entry);
       return 0;
@@ -1049,11 +1194,11 @@ void* GWEN_XMLNode_HandlePath(const char *entry,
   else {
     /* node does exist, check whether this is ok */
     if (
-        ((flags & GWEN_PATH_FLAGS_LAST) &&
-         (flags & GWEN_PATH_FLAGS_NAMEMUSTNOTEXIST)) ||
-        (!(flags & GWEN_PATH_FLAGS_LAST) &&
-         (flags & GWEN_PATH_FLAGS_PATHMUSTNOTEXIST))
-       ) {
+      ((flags & GWEN_PATH_FLAGS_LAST) &&
+       (flags & GWEN_PATH_FLAGS_NAMEMUSTNOTEXIST)) ||
+      (!(flags & GWEN_PATH_FLAGS_LAST) &&
+       (flags & GWEN_PATH_FLAGS_PATHMUSTNOTEXIST))
+    ) {
       DBG_VERBOUS(GWEN_LOGDOMAIN, "Entry \"%s\" already exists", entry);
       return 0;
     }
@@ -1065,24 +1210,24 @@ void* GWEN_XMLNode_HandlePath(const char *entry,
 
 
 GWEN_XMLNODE *GWEN_XMLNode_GetNodeByXPath(GWEN_XMLNODE *n,
-                                          const char *path,
-                                          uint32_t flags){
+    const char *path,
+    uint32_t flags) {
   return (GWEN_XMLNODE*)GWEN_Path_HandleWithIdx(path,
-                                                (void*)n,
-                                                flags,
-                                                GWEN_XMLNode_HandlePath);
+         (void*)n,
+         flags,
+         GWEN_XMLNode_HandlePath);
 }
 
 
 
-GWEN_XMLNODE *GWEN_XMLNode_GetHeader(const GWEN_XMLNODE *n){
+GWEN_XMLNODE *GWEN_XMLNode_GetHeader(const GWEN_XMLNODE *n) {
   assert(n);
   return GWEN_XMLNode_List_First(n->headers);
 }
 
 
 
-void GWEN_XMLNode_AddHeader(GWEN_XMLNODE *n, GWEN_XMLNODE *nh){
+void GWEN_XMLNode_AddHeader(GWEN_XMLNODE *n, GWEN_XMLNODE *nh) {
   assert(n);
   assert(nh);
   GWEN_XMLNode_List_Add(nh, n->headers);
@@ -1090,7 +1235,7 @@ void GWEN_XMLNode_AddHeader(GWEN_XMLNODE *n, GWEN_XMLNODE *nh){
 
 
 
-void GWEN_XMLNode_DelHeader(GWEN_XMLNODE *n, GWEN_XMLNODE *nh){
+void GWEN_XMLNode_DelHeader(GWEN_XMLNODE *n, GWEN_XMLNODE *nh) {
   assert(n);
   assert(nh);
   GWEN_XMLNode_List_Del(nh);
@@ -1098,7 +1243,7 @@ void GWEN_XMLNode_DelHeader(GWEN_XMLNODE *n, GWEN_XMLNODE *nh){
 
 
 
-void GWEN_XMLNode_ClearHeaders(GWEN_XMLNODE *n){
+void GWEN_XMLNode_ClearHeaders(GWEN_XMLNODE *n) {
   assert(n);
   GWEN_XMLNode_List_Clear(n->headers);
 }
@@ -1113,7 +1258,7 @@ GWEN_XMLNODE_NAMESPACE_LIST *GWEN_XMLNode_GetNameSpaces(const GWEN_XMLNODE *n) {
 
 
 GWEN_XMLNODE_NAMESPACE *GWEN_XMLNode_FindNameSpaceByName(const GWEN_XMLNODE *n,
-							 const char *s) {
+    const char *s) {
   GWEN_XMLNODE_NAMESPACE *ns;
 
   assert(n);
@@ -1133,7 +1278,7 @@ GWEN_XMLNODE_NAMESPACE *GWEN_XMLNode_FindNameSpaceByName(const GWEN_XMLNODE *n,
 
 
 GWEN_XMLNODE_NAMESPACE *GWEN_XMLNode_FindNameSpaceByUrl(const GWEN_XMLNODE *n,
-							const char *s) {
+    const char *s) {
   GWEN_XMLNODE_NAMESPACE *ns;
 
   assert(n);
@@ -1170,7 +1315,7 @@ void GWEN_XMLNode_AddNameSpace(GWEN_XMLNODE *n, const GWEN_XMLNODE_NAMESPACE *ns
 
 int GWEN_XML_AddNameSpace(GWEN_STRINGLIST2 *sl,
                           const char *prefix,
-                          const char *name){
+                          const char *name) {
   GWEN_BUFFER *nbuf;
   int rv;
 
@@ -1188,7 +1333,7 @@ int GWEN_XML_AddNameSpace(GWEN_STRINGLIST2 *sl,
 
 
 const char *GWEN_XML_FindNameSpaceByPrefix(GWEN_STRINGLIST2 *sl,
-                                           const char *s){
+    const char *s) {
   GWEN_STRINGLIST2_ITERATOR *it;
 
   it=GWEN_StringList2_First(sl);
@@ -1214,7 +1359,7 @@ const char *GWEN_XML_FindNameSpaceByPrefix(GWEN_STRINGLIST2 *sl,
 
 
 const char *GWEN_XML_FindNameSpaceByName(GWEN_STRINGLIST2 *sl,
-                                         const char *s){
+    const char *s) {
   GWEN_STRINGLIST2_ITERATOR *it;
 
   it=GWEN_StringList2_First(sl);
@@ -1230,8 +1375,8 @@ const char *GWEN_XML_FindNameSpaceByName(GWEN_STRINGLIST2 *sl,
       assert(p);
       p++;
       if (strcasecmp(p, s)==0) {
-	GWEN_StringList2Iterator_free(it);
-	return t;
+        GWEN_StringList2Iterator_free(it);
+        return t;
       }
       t=GWEN_StringList2Iterator_Next(it);
     } /* while */
@@ -1244,7 +1389,7 @@ const char *GWEN_XML_FindNameSpaceByName(GWEN_STRINGLIST2 *sl,
 
 const char *GWEN_XML_FindNameSpace(GWEN_STRINGLIST2 *sl,
                                    const char *prefix,
-                                   const char *name){
+                                   const char *name) {
   GWEN_BUFFER *nbuf;
   GWEN_STRINGLIST2_ITERATOR *it;
 
@@ -1267,9 +1412,9 @@ const char *GWEN_XML_FindNameSpace(GWEN_STRINGLIST2 *sl,
       assert(p);
       p++;
       if (strcasecmp(p, GWEN_Buffer_GetStart(nbuf))==0) {
-	GWEN_StringList2Iterator_free(it);
-	GWEN_Buffer_free(nbuf);
-	return t;
+        GWEN_StringList2Iterator_free(it);
+        GWEN_Buffer_free(nbuf);
+        return t;
       }
       t=GWEN_StringList2Iterator_Next(it);
     } /* while */
@@ -1405,7 +1550,7 @@ int GWEN_XMLNode__CheckAndSetNameSpace(GWEN_XMLNODE *n,
     if (p) {
       if (strncasecmp(n->data, prefix, p-n->data)==0) {
         DBG_DEBUG(GWEN_LOGDOMAIN, "Prefix \"%s\" used in tag \"%s\"",
-                   prefix, n->data);
+                  prefix, n->data);
         inUse=1;
       }
     }
@@ -1418,15 +1563,15 @@ int GWEN_XMLNode__CheckAndSetNameSpace(GWEN_XMLNODE *n,
         if (p) {
           if (strncasecmp(pr->name, prefix, p-pr->name)==0) {
             DBG_DEBUG(GWEN_LOGDOMAIN,
-                       "Prefix \"%s\" used in attribute \"%s\" of tag \"%s\"",
-                       prefix, pr->name, n->data);
+                      "Prefix \"%s\" used in attribute \"%s\" of tag \"%s\"",
+                      prefix, pr->name, n->data);
             inUse=1;
             break;
           }
           else {
             DBG_DEBUG(GWEN_LOGDOMAIN,
-                       "Prefix \"%s\" not used in attribute \"%s\" of tag \"%s\"",
-                       prefix, pr->name, n->data);
+                      "Prefix \"%s\" not used in attribute \"%s\" of tag \"%s\"",
+                      prefix, pr->name, n->data);
           }
         }
         pr=pr->next;
@@ -1442,7 +1587,7 @@ int GWEN_XMLNode__CheckAndSetNameSpace(GWEN_XMLNODE *n,
       if (GWEN_XMLNode_GetProperty(n, "xmlns", 0)==0) {
         /* no, so the current namespace from above is used */
         DBG_DEBUG(GWEN_LOGDOMAIN,
-                   "No prefix, current namespace is used");
+                  "No prefix, current namespace is used");
         inUse=1;
       }
     }
@@ -1520,7 +1665,7 @@ int GWEN_XMLNode__CheckNameSpaceDecls3(GWEN_XMLNODE *n) {
       GWEN_XMLProperty_del(pr, &n->properties);
       rv=GWEN_XMLNode__SetNameSpaces(n, prefix, pr->value);
       DBG_DEBUG(GWEN_LOGDOMAIN, "Removing property \"%s\"",
-                 pr->name);
+                pr->name);
       GWEN_XMLProperty_free(pr);
       if (rv==-1)
         return rv;
@@ -1577,37 +1722,37 @@ int GWEN_XMLNode_StripNamespaces(GWEN_XMLNODE *n) {
 
       p=strchr(n->data, ':');
       if (p) {
-	int len=p-n->data;
-	char *s;
+        int len=p-n->data;
+        char *s;
 
-	n->nameSpace=(char*)GWEN_Memory_malloc(len);
-	assert(n->nameSpace);
-	memmove(n->nameSpace, n->data, len);
-	n->nameSpace[len-1]=0;
-	s=GWEN_Memory_strdup(p+1);
-	free(n->data);
-	n->data=s;
+        n->nameSpace=(char*)GWEN_Memory_malloc(len);
+        assert(n->nameSpace);
+        memmove(n->nameSpace, n->data, len);
+        n->nameSpace[len-1]=0;
+        s=GWEN_Memory_strdup(p+1);
+        free(n->data);
+        n->data=s;
       }
     }
 
     pp=n->properties;
     while(pp) {
       if (pp->nameSpace==0) {
-	char *p;
+        char *p;
 
-	p=strchr(pp->name, ':');
-	if (p) {
-	  int len=p-pp->name;
-	  char *s;
+        p=strchr(pp->name, ':');
+        if (p) {
+          int len=p-pp->name;
+          char *s;
 
-	  pp->nameSpace=(char*)GWEN_Memory_malloc(len);
-	  assert(pp->nameSpace);
-	  memmove(pp->nameSpace, pp->name, len);
-	  pp->nameSpace[len-1]=0;
-	  s=GWEN_Memory_strdup(p+1);
-	  free(pp->name);
-	  pp->name=s;
-	}
+          pp->nameSpace=(char*)GWEN_Memory_malloc(len);
+          assert(pp->nameSpace);
+          memmove(pp->nameSpace, pp->name, len);
+          pp->nameSpace[len-1]=0;
+          s=GWEN_Memory_strdup(p+1);
+          free(pp->name);
+          pp->name=s;
+        }
       }
 
       pp=pp->next;
@@ -1619,7 +1764,7 @@ int GWEN_XMLNode_StripNamespaces(GWEN_XMLNODE *n) {
 
       rv=GWEN_XMLNode_StripNamespaces(nn);
       if (rv<0) {
-	DBG_DEBUG(GWEN_LOGDOMAIN, "here (%d)", rv);
+        DBG_DEBUG(GWEN_LOGDOMAIN, "here (%d)", rv);
         return rv;
       }
       nn=GWEN_XMLNode_List_Next(nn);
@@ -1637,7 +1782,7 @@ int GWEN_XMLNode_StripNamespaces(GWEN_XMLNODE *n) {
 
 
 
-GWEN_XMLNODE_PATH *GWEN_XMLNode_Path_new(void){
+GWEN_XMLNODE_PATH *GWEN_XMLNode_Path_new(void) {
   GWEN_XMLNODE_PATH *p;
 
   GWEN_NEW_OBJECT(GWEN_XMLNODE_PATH, p);
@@ -1646,7 +1791,7 @@ GWEN_XMLNODE_PATH *GWEN_XMLNode_Path_new(void){
 
 
 
-GWEN_XMLNODE_PATH *GWEN_XMLNode_Path_dup(const GWEN_XMLNODE_PATH *np){
+GWEN_XMLNODE_PATH *GWEN_XMLNode_Path_dup(const GWEN_XMLNODE_PATH *np) {
   GWEN_XMLNODE_PATH *p;
   unsigned int i;
 
@@ -1660,14 +1805,14 @@ GWEN_XMLNODE_PATH *GWEN_XMLNode_Path_dup(const GWEN_XMLNODE_PATH *np){
 
 
 
-void GWEN_XMLNode_Path_free(GWEN_XMLNODE_PATH *np){
+void GWEN_XMLNode_Path_free(GWEN_XMLNODE_PATH *np) {
   GWEN_FREE_OBJECT(np);
 }
 
 
 
 int GWEN_XMLNode_Path_Dive(GWEN_XMLNODE_PATH *np,
-                           GWEN_XMLNODE *n){
+                           GWEN_XMLNODE *n) {
   unsigned int i;
 
   if (np->pos>=GWEN_XML_MAX_DEPTH) {
@@ -1686,7 +1831,7 @@ int GWEN_XMLNode_Path_Dive(GWEN_XMLNODE_PATH *np,
 
 
 
-GWEN_XMLNODE *GWEN_XMLNode_Path_Surface(GWEN_XMLNODE_PATH *np){
+GWEN_XMLNODE *GWEN_XMLNode_Path_Surface(GWEN_XMLNODE_PATH *np) {
   if (np->pos==0) {
     DBG_DEBUG(GWEN_LOGDOMAIN, "Root reached");
     return 0;
@@ -1697,7 +1842,7 @@ GWEN_XMLNODE *GWEN_XMLNode_Path_Surface(GWEN_XMLNODE_PATH *np){
 
 
 
-void GWEN_XMLNode_Path_Dump(GWEN_XMLNODE_PATH *np){
+void GWEN_XMLNode_Path_Dump(GWEN_XMLNODE_PATH *np) {
   unsigned int i;
 
   if (np->pos==0) {
@@ -1720,7 +1865,7 @@ void GWEN_XMLNode_Path_Dump(GWEN_XMLNODE_PATH *np){
 
 
 GWEN_XMLNODE_NAMESPACE *GWEN_XMLNode_NameSpace_new(const char *name,
-						   const char *url) {
+    const char *url) {
   GWEN_XMLNODE_NAMESPACE *ns;
 
   GWEN_NEW_OBJECT(GWEN_XMLNODE_NAMESPACE, ns);
