@@ -42,6 +42,7 @@ struct GWEN__XMLPROPERTY {
   GWEN_XMLPROPERTY *next;
   char *name;
   char *value;
+  char *nameSpace;
 };
 
 
@@ -87,24 +88,24 @@ struct GWEN_XMLNODE_NAMESPACE {
 
 
 static void GWEN_XMLNode__SetProperty(GWEN_XMLNODE *n,
-				      const char *name, const char *value,
-				      int doInsert);
+                                      const char *name, const char *value,
+                                      int doInsert);
 
 static int GWEN_XMLNode__WriteToStream(const GWEN_XMLNODE *n,
                                        GWEN_FAST_BUFFER *fb,
-				       uint32_t flags,
-				       unsigned int ind);
+                                       uint32_t flags,
+                                       unsigned int ind);
 
 
 static GWEN_XMLNODE *GWEN_XMLNode_GetFirstOfType(const GWEN_XMLNODE *n,
-						 GWEN_XMLNODE_TYPE t);
+    GWEN_XMLNODE_TYPE t);
 static GWEN_XMLNODE *GWEN_XMLNode_GetNextOfType(const GWEN_XMLNODE *n,
-						GWEN_XMLNODE_TYPE t);
+    GWEN_XMLNODE_TYPE t);
 
 static GWEN_XMLNODE *GWEN_XMLNode_FindTag(const GWEN_XMLNODE *n,
-					  const char *tname,
-					  const char *pname,
-					  const char *pvalue);
+    const char *tname,
+    const char *pname,
+    const char *pvalue);
 
 
 /**
@@ -112,8 +113,8 @@ static GWEN_XMLNODE *GWEN_XMLNode_FindTag(const GWEN_XMLNODE *n,
  * level.
  */
 static int GWEN_XMLNode__CheckNameSpaceDecls1(GWEN_XMLNODE *n,
-					      GWEN_STRINGLIST2 *sl,
-					      const char *currentNameSpace);
+    GWEN_STRINGLIST2 *sl,
+    const char *currentNameSpace);
 
 /**
  * Moves all namespace declarations from this node to the nodes
@@ -123,35 +124,36 @@ static int GWEN_XMLNode__CheckNameSpaceDecls3(GWEN_XMLNODE *n);
 
 
 static int GWEN_XMLNode__SetNameSpaces(GWEN_XMLNODE *n,
-				       const char *prefix,
-				       const char *nspace);
+                                       const char *prefix,
+                                       const char *nspace);
 static int GWEN_XMLNode__CheckAndSetNameSpace(GWEN_XMLNODE *n,
-					      const char *prefix,
-					      const char *nspace);
+    const char *prefix,
+    const char *nspace);
 
 static int GWEN_XML__ReadData(GWEN_XML_CONTEXT *ctx,
-			      GWEN_FAST_BUFFER *fb,
-			      uint32_t flags);
+                              GWEN_FAST_BUFFER *fb,
+                              uint32_t flags);
 
 static int GWEN_XML__ReadTag(GWEN_XML_CONTEXT *ctx,
-			     GWEN_FAST_BUFFER *fb,
-			     uint32_t flags);
+                             GWEN_FAST_BUFFER *fb,
+                             uint32_t flags,
+                             GWEN_BUFFER *workBuf);
 
-static int GWEN_XML__ReadAllFromIo(GWEN_XML_CONTEXT *ctx, GWEN_IO_LAYER *io);
+static int GWEN_XML__ReadAllFromIo(GWEN_XML_CONTEXT *ctx, GWEN_SYNCIO *sio);
 
 
 static GWEN_XMLNODE_NAMESPACE *GWEN_XMLGL__GetNameSpaceByPrefix(GWEN_XMLNODE *n,
-								const char *prefix);
+    const char *prefix);
 
 static int GWEN_XMLGL__SampleNameSpaces(GWEN_XMLNODE *n,
-					GWEN_XMLNODE_NAMESPACE_LIST *l,
-					uint32_t *pLastId);
+                                        GWEN_XMLNODE_NAMESPACE_LIST *l,
+                                        uint32_t *pLastId);
 
 static void GWEN_XMLGL__ClearNameSpaces(GWEN_XMLNODE *n);
 
 static int GWEN_XMLGL__TranslateName(GWEN_XMLNODE *n,
-				     GWEN_XMLNODE_NAMESPACE_LIST *l,
-				     char **pValue);
+                                     GWEN_XMLNODE_NAMESPACE_LIST *l,
+                                     char **pValue);
 
 
 #endif
