@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
- -------------------
- cvs         : $Id: main.c 1107 2007-01-07 21:17:05Z martin $
  begin       : Tue May 03 2005
- copyright   : (C) 2005 by Martin Preuss
+ copyright   : (C) 2005-2010 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -51,14 +48,14 @@ int getKeyDataFromTextOpenSSL(GWEN_GUI *gui,
 			      const char *password,
 			      unsigned char *buffer,
 			      unsigned int bsize) {
-  des_cblock left, right;
+  DES_cblock left, right;
   int i;
 
   if (bsize!=16) {
     DBG_ERROR(GWEN_LOGDOMAIN, "Buffer must be exact 16 bytes in length");
     return -1;
   }
-  des_string_to_2keys(password, &left, &right);
+  DES_string_to_2keys(password, &left, &right);
   for (i=0; i<8; i++)
     *(buffer++)=left[i];
   for (i=0; i<8; i++)
@@ -227,6 +224,9 @@ int main(int argc, char **argv) {
 			     I18N("  update:\n"
 				  "    Update Crypt Token to newer version (e.g. OpenHBCI key"
 				  "files)\n\n"));
+    GWEN_Buffer_AppendString(ubuf,
+			     I18N("  showpasswords:\n"
+				  "    Display passwords store in a GWEN_PASSWD_STORE file\n\n"));
 
     fprintf(stderr, "%s\n", GWEN_Buffer_GetStart(ubuf));
     GWEN_Buffer_free(ubuf);
@@ -255,6 +255,9 @@ int main(int argc, char **argv) {
   else if (strcasecmp(cmd, "genkey")==0) {
     rv=genKey(db, argc, argv);
   }
+  else if (strcasecmp(cmd, "activatekey")==0) {
+    rv=activateKey(db, argc, argv);
+  }
   else if (strcasecmp(cmd, "update")==0) {
     rv=updateToken(db, argc, argv);
   }
@@ -267,6 +270,15 @@ int main(int argc, char **argv) {
   else if (strcasecmp(cmd, "setkey")==0) {
     rv=setKey(db, argc, argv);
   }
+  else if (strcasecmp(cmd, "hashTree")==0) {
+    rv=hashTree(db, argc, argv);
+  }
+  else if (strcasecmp(cmd, "checkTree")==0) {
+    rv=checkTree(db, argc, argv);
+  }
+  else if (strcasecmp(cmd, "showpasswords")==0) {
+    rv=showPasswords(db, argc, argv);
+  }
   else {
     fprintf(stderr, "ERROR: Unknown command \"%s\".\n", cmd);
     rv=1;
